@@ -1,5 +1,5 @@
 ;;; emacspeak-ansi-color.el --- Speech-enable ansi-color terminal
-;;; $Id: emacspeak-ansi-color.el 5222 2007-08-26 01:28:19Z tv.raman.tv $
+;;; $Id: emacspeak-ansi-color.el 8243 2013-03-19 15:32:44Z tv.raman.tv $
 ;;; $Author: tv.raman.tv $
 ;;; Description:  Emacspeak module for ansi-color
 ;;; Keywords: Emacspeak, ansi-color
@@ -8,7 +8,7 @@
 ;;; LCD Archive Entry:
 ;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
 ;;; A speech interface to Emacs |
-;;; $Date: 2007-08-25 18:28:19 -0700 (Sat, 25 Aug 2007) $ |
+;;; $Date: 2007-12-09 17:51:46 -0800 (Sun, 09 Dec 2007) $ |
 ;;;  $Revision: 4502 $ |
 ;;; Location undetermined
 ;;;
@@ -16,7 +16,7 @@
 ;;}}}
 ;;{{{  Copyright:
 
-;;; Copyright (C) 1999 T. V. Raman <raman@cs.cornell.edu>
+;;; Copyright (C) 1999, 2011 T. V. Raman <raman@cs.cornell.edu>
 ;;; All Rights Reserved.
 ;;;
 ;;; This file is not part of GNU Emacs, but the same permissions apply.
@@ -60,37 +60,39 @@
   "Return a voice corresponding to specified face-spec."
   (declare (special ansi-color-names-vector
                     ansi-color-faces-vector))
-  (let* ((voice-name nil)
-         (style (cadr face-spec))
-         (style-index (position style ansi-color-faces-vector))
-         (color (cdr (assq 'foreground-color  face-spec)))
-         (color-index
-          (when color
-            (position  color ansi-color-names-vector
-                       :test #'string-equal)))
-         (style nil)
-         (color-parameter nil)
-         (style-parameter nil))
-    (setq voice-name
-          (intern (format "emacspeak-ansi-color-%s-%s"
-                          (if color color "default")
-                          (if style style "default"))))
-    (unless (tts-voice-defined-p voice-name)
-      (setq style (make-acss ))
-      (setq style-parameter
-            (if style-index
-                (+ 1 style-index)
-              1))
-      (setq color-parameter
-            (if color-index
-                (+ 1 color-index)
-              1))
-      (setf (acss-average-pitch style) color-parameter)
-      (setf (acss-pitch-range style) color-parameter)
-      (setf (acss-richness style) color-parameter)
-      (setf (acss-stress style) color-parameter)
-      (tts-define-voice-from-speech-style voice-name style))
-    voice-name))
+  (condition-case nil
+      (let* ((voice-name nil)
+             (style (cadr face-spec))
+             (style-index (position style ansi-color-faces-vector))
+             (color (cdr (assq 'foreground-color  face-spec)))
+             (color-index
+              (when color
+                (position  color ansi-color-names-vector
+                           :test #'string-equal)))
+             (style nil)
+             (color-parameter nil)
+             (style-parameter nil))
+        (setq voice-name
+              (intern (format "emacspeak-ansi-color-%s-%s"
+                              (if color color "default")
+                              (if style style "default"))))
+        (unless (tts-voice-defined-p voice-name)
+          (setq style (make-acss ))
+          (setq style-parameter
+                (if style-index
+                    (+ 1 style-index)
+                  1))
+          (setq color-parameter
+                (if color-index
+                    (+ 1 color-index)
+                  1))
+          (setf (acss-average-pitch style) color-parameter)
+          (setf (acss-pitch-range style) color-parameter)
+          (setf (acss-richness style) color-parameter)
+          (setf (acss-stress style) color-parameter)
+          (tts-define-voice-from-speech-style voice-name style))
+        voice-name)
+    (error nil)))
 
 (defadvice ansi-color-set-extent-face (after emacspeak pre act comp)
   "Apply aural properties."
@@ -101,9 +103,9 @@
          (voice (when (listp face)
                   (emacspeak-ansi-color-to-voice face))))
     (when voice
-      (ems-modify-buffer-safely
-       (put-text-property start end
-                          'personality voice)))))
+      (funcall emacspeak-personality-voiceify-faces
+               start end
+               voice nil))))
 
 ;;}}}
 ;;{{{ advice interactive commands
@@ -111,14 +113,14 @@
 (defadvice ansi-color-for-comint-mode-on (after emacspeak
                                                 pre act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'on)
     (message "Ansi escape sequences will be processed.")))
 
 (defadvice ansi-color-for-comint-mode-off (after emacspeak
                                                  pre act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'off)
     (message "Ansi escape sequences will not be processed.")))
 
@@ -128,7 +130,7 @@
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: t
+;;; byte-compile-dynamic: nil
 ;;; end:
 
 ;;}}}
