@@ -1,6 +1,6 @@
-;;; emacspeak-perl.el --- Speech enable CPerl Mode 
-;;; $Id: emacspeak-cperl.el,v 23.505 2005/11/25 16:30:50 raman Exp $
-;;; $Author: raman $ 
+;;; emacspeak-cperl.el --- Speech enable CPerl Mode 
+;;; $Id: emacspeak-cperl.el 8146 2013-02-09 20:05:08Z tv.raman.tv $
+;;; $Author: tv.raman.tv $ 
 ;;; DescriptionEmacspeak extensions for CPerl mode
 ;;; Keywords:emacspeak, audio interface to emacs CPerl
 ;;{{{  LCD Archive entry: 
@@ -8,14 +8,14 @@
 ;;; LCD Archive Entry:
 ;;; emacspeak| T. V. Raman |raman@cs.cornell.edu 
 ;;; A speech interface to Emacs |
-;;; $Date: 2005/11/25 16:30:50 $ |
-;;;  $Revision: 23.505 $ | 
+;;; $Date: 2007-09-01 15:30:13 -0700 (Sat, 01 Sep 2007) $ |
+;;;  $Revision: 4532 $ | 
 ;;; Location undetermined
 ;;;
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2004, T. V. Raman 
+;;;Copyright (C) 1995 -- 2011, T. V. Raman 
 ;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
 ;;; All Rights Reserved. 
 ;;;
@@ -65,23 +65,24 @@
     cperl-electric-semi
     cperl-electric-terminator)
   "Electric commands from CPerl to advice")
-
-(loop for e in emacspeak-cperl-electric-insertion-commands-to-advice
-      do
-      (eval
-       (`
-        (defadvice (, e) (after emacspeak pre act comp)
-          "Speak what you inserted.
+(unless (and (boundp 'post-self-insert-hook)
+             post-self-insert-hook
+             (memq 'emacspeak-post-self-insert-hook post-self-insert-hook))
+  (loop for e in emacspeak-cperl-electric-insertion-commands-to-advice
+        do
+        (eval
+         `(defadvice ,e (after emacspeak pre act comp)
+            "Speak what you inserted.
 Cue electric insertion with a tone."
-          (when (interactive-p)
-            (let ((emacspeak-speak-messages nil))
-	      (emacspeak-speak-this-char last-input-char)
-	      (dtk-tone 800 50 t)))))))
+            (when (ems-interactive-p )
+              (let ((emacspeak-speak-messages nil))
+                (emacspeak-speak-this-char last-input-event)
+                (dtk-tone 800 50 t)))))))
 
 (defadvice cperl-electric-backspace (around emacspeak pre act)
   "Speak character you're deleting."
   (cond
-   ((interactive-p )
+   ((ems-interactive-p  )
     (dtk-tone 500 30 'force)
     (emacspeak-speak-this-char (preceding-char ))
     ad-do-it)
@@ -94,7 +95,7 @@ Cue electric insertion with a tone."
 Otherwise cue user to the line just created. "
   (declare (special emacspeak-line-echo ))
   (cond
-   ((interactive-p)
+   ((ems-interactive-p )
     (cond
      (emacspeak-line-echo 
       (emacspeak-speak-line )
@@ -110,7 +111,7 @@ Otherwise cue user to the line just created. "
 
 (defadvice cperl-indent-exp  (after emacspeak pre act)
   "Provide auditory feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'fill-object )
     (message "Indented current s expression ")))
 
@@ -119,15 +120,15 @@ Otherwise cue user to the line just created. "
 
 (defadvice cperl-info-on-current-command (after emacspeak pre act comp)
   "Speak the displayed info"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'help)
     (message "Displayed info in other window")))
 
 (defadvice cperl-info-on-command (after emacspeak
-					pre act
-					comp)
+                                        pre act
+                                        comp)
   "Speak the displayed info"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'help)
     (message "Displayed help in other window.")))
 
@@ -137,13 +138,13 @@ Otherwise cue user to the line just created. "
 (defadvice cperl-invert-if-unless (after emacspeak pre act
                                          comp)
   "Speak updated line"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-speak-line)
     (emacspeak-auditory-icon 'select-object)))
 
 (defadvice cperl-comment-region (after emacspeak pre act )
   "Provide spoken feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (let ((prefix-arg (ad-get-arg 2)))
       (message "%s region containing %s lines"
                (if (and prefix-arg
@@ -154,7 +155,7 @@ Otherwise cue user to the line just created. "
 
 (defadvice cperl-uncomment-region (after emacspeak pre act )
   "Provide spoken feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (let ((prefix-arg (ad-get-arg 2)))
       (message "%s region containing %s lines"
                (if (and prefix-arg
@@ -166,21 +167,21 @@ Otherwise cue user to the line just created. "
 (defadvice cperl-indent-command (after emacspeak pre act
                                        comp)
   "Provide auditory feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-speak-line)
     (emacspeak-auditory-icon 'large-movement)))
 
 (defadvice cperl-indent-region (after emacspeak pre act
                                       comp)
   "Provide auditory feedback when done"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'fill-object)
     (message "Filled region containing %s lines"
              (count-lines (region-beginning)
                           (region-end)))))
 (defadvice cperl-fill-paragraph (after emacspeak pre act)
   "Provide auditory feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'fill-object )
     (message "Filled current paragraph")))
 ;;}}}
@@ -189,14 +190,14 @@ Otherwise cue user to the line just created. "
 (defadvice cperl-switch-to-doc-buffer (after emacspeak pre
                                              act comp)
   "Provide auditory feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-speak-mode-line)
     (emacspeak-auditory-icon 'open-object)))
 
 (defadvice cperl-find-bad-style (after emacspeak pre act
                                        comp)
   "Provide auditory feedback when done."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-speak-mode-line)
     (emacspeak-auditory-icon 'task-done)))
 ;;}}}
@@ -204,13 +205,12 @@ Otherwise cue user to the line just created. "
 
 (add-hook 'cperl-mode-hook
           (function (lambda ()
-		      (voice-lock-mode 1)
-		      (dtk-set-punctuations 'all)
-		      (or dtk-split-caps
-			  (dtk-toggle-split-caps))
-		      (or emacspeak-audio-indentation
-			  (emacspeak-toggle-audio-indentation))
-		      (emacspeak-dtk-sync))))
+                      (dtk-set-punctuations 'all)
+                      (or dtk-split-caps
+                          (dtk-toggle-split-caps))
+                      (or emacspeak-audio-indentation
+                          (emacspeak-toggle-audio-indentation))
+                      (emacspeak-dtk-sync))))
 
 ;;}}}
 (provide  'emacspeak-cperl)
@@ -218,7 +218,7 @@ Otherwise cue user to the line just created. "
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: t
+;;; byte-compile-dynamic: nil
 ;;; end: 
 
 ;;}}}
