@@ -3,18 +3,18 @@
 ;;; Code:
 
 (put 'accessibility 'custom-loads '(emacspeak))
+(put 'amixer 'custom-loads '(amixer))
 (put 'applications 'custom-loads '(emacspeak))
 (put 'cd-tool 'custom-loads '(cd-tool))
 (put 'dtk 'custom-loads '(dtk-speak))
 (put 'dtk-unicode 'custom-loads '(dtk-unicode))
-(put 'emacspeak 'custom-loads '(dtk-speak dtk-unicode emacspeak emacspeak-add-log emacspeak-advice emacspeak-alsaplayer emacspeak-aumix emacspeak-bookshare emacspeak-daisy emacspeak-dbus emacspeak-dismal emacspeak-epub emacspeak-erc emacspeak-eshell emacspeak-eterm emacspeak-eudc emacspeak-feeds emacspeak-flyspell emacspeak-forms emacspeak-gnus emacspeak-ido emacspeak-ispell emacspeak-jss emacspeak-keymap emacspeak-kite emacspeak-librivox emacspeak-m-player emacspeak-message emacspeak-midge emacspeak-npr emacspeak-nxml emacspeak-ocr emacspeak-pronounce emacspeak-replace emacspeak-sounds emacspeak-speak emacspeak-speedbar emacspeak-table-ui emacspeak-vm emacspeak-w3 emacspeak-w3m emacspeak-we emacspeak-websearch emacspeak-widget emacspeak-wizards emacspeak-xml-shell emacspeak-xslt voice-setup))
+(put 'emacspeak 'custom-loads '(dtk-speak dtk-unicode emacspeak emacspeak-add-log emacspeak-advice emacspeak-alsaplayer emacspeak-aumix emacspeak-bookshare emacspeak-dbus emacspeak-dismal emacspeak-epub emacspeak-erc emacspeak-eshell emacspeak-eterm emacspeak-eudc emacspeak-feeds emacspeak-flyspell emacspeak-forms emacspeak-gnus emacspeak-ido emacspeak-ispell emacspeak-jss emacspeak-keymap emacspeak-kite emacspeak-librivox emacspeak-m-player emacspeak-message emacspeak-midge emacspeak-npr emacspeak-nxml emacspeak-ocr emacspeak-pronounce emacspeak-replace emacspeak-sounds emacspeak-speak emacspeak-speedbar emacspeak-table-ui emacspeak-vm emacspeak-w3 emacspeak-w3m emacspeak-we emacspeak-websearch emacspeak-widget emacspeak-wizards emacspeak-xml-shell emacspeak-xslt voice-setup))
 (put 'emacspeak-advice 'custom-loads '(emacspeak-advice))
 (put 'emacspeak-alsaplayer 'custom-loads '(emacspeak-alsaplayer))
 (put 'emacspeak-aumix 'custom-loads '(emacspeak-aumix))
 (put 'emacspeak-bookshare 'custom-loads '(emacspeak-bookshare))
 (put 'emacspeak-calendar 'custom-loads '(emacspeak-calendar))
 (put 'emacspeak-custom 'custom-loads '(emacspeak-custom))
-(put 'emacspeak-daisy 'custom-loads '(emacspeak-daisy))
 (put 'emacspeak-dbus 'custom-loads '(nm))
 (put 'emacspeak-dired 'custom-loads '(emacspeak-dired))
 (put 'emacspeak-dismal 'custom-loads '(emacspeak-dismal))
@@ -22,6 +22,7 @@
 (put 'emacspeak-epub 'custom-loads '(emacspeak-epub))
 (put 'emacspeak-erc 'custom-loads '(emacspeak-erc))
 (put 'emacspeak-eshell 'custom-loads '(emacspeak-eshell))
+(put 'emacspeak-espn 'custom-loads '(emacspeak-espn))
 (put 'emacspeak-eterm 'custom-loads '(emacspeak-eterm))
 (put 'emacspeak-eudc 'custom-loads '(emacspeak-eudc))
 (put 'emacspeak-eww 'custom-loads '(emacspeak-eww))
