@@ -1,5 +1,5 @@
 ;;; emacspeak-custom.el --- Speech enable interactive Emacs customization 
-;;; $Id: emacspeak-custom.el 5246 2007-09-01 22:30:13Z tv.raman.tv $
+;;; $Id: emacspeak-custom.el 9115 2014-04-30 16:12:41Z tv.raman.tv $
 ;;; $Author: tv.raman.tv $ 
 ;;; Description: Auditory interface to custom
 ;;; Keywords: Emacspeak, Speak, Spoken Output, custom
@@ -16,7 +16,7 @@
 ;;}}}
 ;;{{{  Copyright:
 
-;;; Copyright (c) 1995 -- 2007, T. V. Raman
+;;; Copyright (c) 1995 -- 2011, T. V. Raman
 ;;; All Rights Reserved. 
 ;;;
 ;;; This file is not part of GNU Emacs, but the same permissions apply.
@@ -41,6 +41,8 @@
 ;;{{{  Required modules
 
 (require 'emacspeak-preamble)
+(eval-when-compile (load-library "cus-edit")
+                   (provide 'cus-edit))
 ;;}}}
 ;;{{{  Introduction
 
@@ -54,120 +56,117 @@
 
 (defadvice Custom-reset-current (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'item)
     (dtk-speak "Reset current")))
 
 (defadvice Custom-reset-saved(after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'unmodified-object)
     (dtk-speak "Reset to saved")))
 
 (defadvice Custom-reset-standard (after emacspeak act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'delete-object)
     (dtk-speak "Erase customization")))
 
 (defadvice Custom-set (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'button)
     (dtk-speak "Set for current session")))
 
 (defadvice Custom-save (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'save-object)
     (dtk-speak "Set and saved")))
 
 (defadvice Custom-buffer-done (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'close-object)
     (emacspeak-speak-line)))
 
 (defadvice customize-save-customized (after emacspeak pre act comp)
   "Provide auditory feedback. "
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'save-object)
     (message "Saved customizations.")))
 
-(defadvice custom-save-all (after emacspeak pre
-                                  act comp)
+(defadvice custom-save-all (after emacspeak pre act comp)
   "Provide auditory feedback. "
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'save-object)
     (message "Saved customizations.")))
+
+(defadvice customize-save-customized (around quiet pre act comp)
+  "Silence speech."
+  (let ((dtk-quiet t)) ad-do-it))
+
 (defadvice custom-set (after emacspeak pre act comp)
   "Provide auditory feedback. "
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'mark-object)
     (message "Set all updates.")))
 
 (defadvice customize (after emacspeak pre act comp)
   "Provide auditory feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'open-object)
-    (voice-lock-mode 1)
     (emacspeak-custom-goto-group)
     (emacspeak-speak-line)))
 
 (defadvice customize-group (after emacspeak pre act comp)
   "Provide auditory feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'open-object)
     (emacspeak-custom-goto-group)
-    (voice-lock-mode 1)
     (emacspeak-speak-line)))
 
 (defadvice customize-browse (after emacspeak pre act comp)
   "Provide auditory feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'open-object)
-    (voice-lock-mode 1)
     (emacspeak-speak-mode-line)))
 
 (defadvice customize-option (after emacspeak pre act comp)
   "Provide auditory feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (let ((symbol (ad-get-arg 0)))
       (emacspeak-auditory-icon 'open-object)
       (search-forward (custom-unlispify-tag-name symbol))
       (beginning-of-line)
-      (voice-lock-mode 1)
       (emacspeak-speak-line))))
 
 (defadvice customize-apropos (after emacspeak pre act comp)
   "Provide auditory feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (let ((symbol (ad-get-arg 0)))
       (emacspeak-auditory-icon 'open-object)
-      (voice-lock-mode 1)
       (beginning-of-line)
       (emacspeak-speak-line))))
 
 (defadvice customize-variable (after emacspeak pre act comp)
   "Provide auditory feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (let ((symbol (ad-get-arg 0)))
       (emacspeak-auditory-icon 'open-object)
-      (voice-lock-mode 1)
       (search-forward (custom-unlispify-tag-name symbol))
       (beginning-of-line)
       (emacspeak-speak-line))))
 
 (defadvice Custom-goto-parent (after emacspeak pre act comp)
   "Provide auditory feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'large-movement)
-    (voice-lock-mode 1)
     (emacspeak-speak-line)))
 
 (defadvice Custom-newline (after emacspeak pre act comp)
   "Provide auditory feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'button)))
 
 ;;}}}
@@ -176,7 +175,6 @@
 (add-hook 'custom-mode-hook
           (function
            (lambda nil
-             (voice-lock-mode 1)
              (emacspeak-pronounce-refresh-pronunciations))))
 
 ;;}}}
@@ -189,19 +187,17 @@
    (custom-button-mouse voice-bolden-medium)
    (custom-button-unraised voice-smoothen)
    (custom-changed voice-smoothen)
-   (custom-comment-face voice-monotone-medium)
+   (custom-comment voice-monotone-medium)
    (custom-comment-tag voice-monotone)
-   (custom-comment-tag-face voice-monotone)
    (custom-documentation voice-brighten-medium)
    (custom-face-tag voice-lighten)
    (custom-group-tag voice-bolden)
    (custom-group-tag-1 voice-lighten-medium)
-   (custom-group-tag-face voice-bolden)
    (custom-invalid voice-animate-extra)
    (custom-link voice-bolden)
    (custom-modified voice-lighten-medium)
    (custom-rogue voice-bolden-and-animate)
-   (custom-modified-face voice-lighten-medium)
+   (custom-modified voice-lighten-medium)
    (custom-saved voice-smoothen-extra)
    (custom-set voice-smoothen-medium)
    (custom-state voice-smoothen)
@@ -270,7 +266,7 @@
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: t
+;;; byte-compile-dynamic: nil
 ;;; end: 
 
 ;;}}}
