@@ -1,5 +1,5 @@
 ;;; emacspeak-dired.el --- Speech enable Dired Mode -- A powerful File Manager
-;;; $Id: emacspeak-dired.el 8574 2013-11-24 02:01:07Z tv.raman.tv $
+;;; $Id: emacspeak-dired.el 9092 2014-04-23 00:26:17Z tv.raman.tv $
 ;;; $Author: tv.raman.tv $
 ;;; Description:  Emacspeak extension to speech enable dired
 ;;; Keywords: Emacspeak, Dired, Spoken Output
@@ -54,42 +54,24 @@
 (require 'dired)
 ;;}}}
 ;;{{{ Define personalities
+
 (voice-setup-add-map
  '(
    (dired-header voice-smoothen)
    (dired-mark voice-lighten)
-   (dired-marked voice-bolden-and-animate)
+   (dired-perm-write voice-lighten-extra)
+   (dired-marked voice-lighten)
    (dired-warning voice-animate-extra)
    (dired-directory voice-bolden-medium)
    (dired-symlink voice-animate-extra)
    (dired-ignored voice-lighten-extra)
    (dired-flagged voice-animate-extra)
    ))
-;;}}}
-;;{{{  configure dired
-;;; Not touching dired-listing-switches 
-;;; Emacspeak in 1994 forcibly set this to  a safe value
-;;; Removing in 2013, since we've now had custom for 13+ years.
-
-(defvar emacspeak-dired-pronunciations-defined nil
-  "Internal variable used to ensure we define dired
-pronunciations only once.")
-
-(defun emacspeak-dired-define-pronunciations ()
-  "Define pronunciations specific to Dired buffers."
-  (declare (special emacspeak-dired-pronunciations-defined
-                    emacspeak-pronounce-pronunciation-table emacspeak-pronounce-dictionaries-loaded))
-  (unless emacspeak-dired-pronunciations-defined
-    (setq emacspeak-dired-pronunciations-defined t)
-    (emacspeak-pronounce-add-dictionary-entry 'dired-mode "Dired" " DirEd  "))
-  (when (or (not (boundp 'emacspeak-pronounce-pronunciation-table))
-            (not emacspeak-pronounce-pronunciation-table))
-    (emacspeak-pronounce-toggle-use-of-dictionaries)))
 
 ;;}}}
 ;;{{{  functions:
 
-(defun emacspeak-dired-speak-line ()
+(defsubst emacspeak-dired-speak-line ()
   "Speak the dired line intelligently."
   (declare (special emacspeak-speak-last-spoken-word-position))
   (let ((filename (dired-get-filename 'no-dir  t ))
@@ -105,8 +87,7 @@ pronunciations only once.")
 ;;}}}
 ;;{{{  advice:
 
-(defadvice dired-sort-toggle-or-edit (around emacspeak pre
-                                             act comp)
+(defadvice dired-sort-toggle-or-edit (around emacspeak pre act comp)
   "Provide auditory feedback."
   (cond
    ((ems-interactive-p )
@@ -127,22 +108,22 @@ pronunciations only once.")
     (emacspeak-auditory-icon 'close-object)
     (emacspeak-speak-mode-line)))
 
-(defadvice dired-up-directory (after emacspeak pre act)
-  "Produce an auditory icon."
-  (when (ems-interactive-p )
-    (let ((emacspeak-speak-messages nil))
-      (emacspeak-dired-label-fields)
-      (emacspeak-auditory-icon 'open-object )
-      (emacspeak-speak-mode-line))))
 (defun emacspeak-dired-initialize ()
   "Set up emacspeak dired."
   (emacspeak-dired-label-fields)
-  (emacspeak-auditory-icon 'open-object )
-  (emacspeak-speak-mode-line))
-
-(defadvice dired (after emacspeak pre act comp)
-  "Hook is not reliable."
-  (emacspeak-dired-initialize))
+  (emacspeak-dired-setup-keys))
+(loop
+ for  f in
+ '(dired ido-dired
+         dired-other-window dired-other-frame)
+ do
+ (eval
+  `(defadvice ,f (after emacspeak pre act comp)
+     "Set up emacspeak."
+     (when (ems-interactive-p)
+       (emacspeak-dired-initialize)
+       (emacspeak-auditory-icon 'open-object )
+       (emacspeak-speak-mode-line)))))
 
 (defadvice dired-find-file  (around  emacspeak pre act)
   "Produce an auditory icon."
@@ -155,71 +136,34 @@ pronunciations only once.")
       (emacspeak-auditory-icon 'open-object )))
    (t ad-do-it))
   ad-return-value)
+(loop
+ for  f in
+ '(
+   dired-next-subdir dired-prev-subdir
+                     dired-tree-up dired-tree-down dired-up-directory
+                     dired-next-marked-file dired-prev-marked-file
+                     dired-next-dirline dired-prev-dirline
+                     dired-jump
+                     )
+ do
+ (eval
+  `(defadvice ,f (after emacspeak pre act)
+     "Speak the filename."
+     (when (ems-interactive-p  )
+       (emacspeak-auditory-icon 'large-movement)
+       (emacspeak-dired-speak-line)))))
 
-(defadvice dired-tree-up (after emacspeak pre act)
-  "Speak the filename."
-  (when (ems-interactive-p  )
-    (emacspeak-auditory-icon 'large-movement)
-    (emacspeak-dired-speak-line)))
-
-(defadvice dired-tree-down (after emacspeak pre act)
-  "Speak the filename."
-  (when (ems-interactive-p  )
-    (emacspeak-auditory-icon 'large-movement)
-    (emacspeak-dired-speak-line)))
-
-(defadvice dired-next-line (after emacspeak pre act)
-  "Speak the filename name."
-  (when (ems-interactive-p  )
-    (emacspeak-auditory-icon 'select-object)
-    (emacspeak-dired-speak-line)))
-
-(defadvice dired-previous-line (after emacspeak pre act)
-  "Speak the filename name."
-  (when (ems-interactive-p  )
-    (emacspeak-auditory-icon 'select-object)
-    (emacspeak-dired-speak-line)))
-
-(defadvice dired-next-marked-file (after emacspeak pre act)
-  "Speak the filename name."
-  (when (ems-interactive-p  )
-    (emacspeak-auditory-icon 'large-movement)
-    (emacspeak-dired-speak-line)))
-
-(defadvice dired-prev-marked-file  (after emacspeak pre act)
-  "Speak the filename name."
-  (when (ems-interactive-p  )
-    (emacspeak-auditory-icon 'large-movement)
-    (emacspeak-dired-speak-line)))
-
-(defadvice dired-prev-subdir (after emacspeak pre act)
-  "Speak the filename name."
-  (when (ems-interactive-p  )
-    (emacspeak-auditory-icon 'large-movement)
-    (emacspeak-dired-speak-line)))
-
-(defadvice dired-next-subdir (after emacspeak pre act)
-  "Speak the filename name."
-  (when (ems-interactive-p  )
-    (emacspeak-auditory-icon 'large-movement)
-    (emacspeak-dired-speak-line)))
-
-(defadvice dired-next-dirline (after emacspeak pre act)
-  "Speak the filename name."
-  (when (ems-interactive-p  )
-    (emacspeak-auditory-icon 'large-movement)
-    (emacspeak-dired-speak-line)))
-
-(defadvice dired-prev-dirline (after emacspeak pre act)
-  "Speak the filename name."
-  (when (ems-interactive-p  )
-    (emacspeak-auditory-icon 'large-movement)
-    (emacspeak-dired-speak-line)))
-
-(defadvice dired-unmark-backward (after emacspeak pre act)
-  "Speak the filename name."
-  (when (ems-interactive-p  )
-    (emacspeak-dired-speak-line)))
+(loop
+ for f in
+ '(dired-next-line dired-previous-line
+                   dired-unmark-backward dired-maybe-insert-subdir)
+ do
+ (eval
+  `(defadvice ,f  (after emacspeak pre act)
+     "Speak the filename name."
+     (when (ems-interactive-p  )
+       (emacspeak-auditory-icon 'select-object)
+       (emacspeak-dired-speak-line)))))
 
 ;;; Producing auditory icons:
 ;;; These dired commands do some action that causes a state change:
@@ -298,6 +242,7 @@ unless `dired-listing-switches' contains -l"
 
 ;;}}}
 ;;{{{ Additional status speaking commands
+
 (defcustom emacspeak-dired-file-cmd-options "-b"
   "Options passed to Unix builtin `file' command."
   :type '(choice
@@ -418,9 +363,8 @@ On a directory line, run du -s on the directory to speak its size."
   (define-key dired-mode-map "\C-t" 'emacspeak-dired-speak-symlink-target)
   (define-key dired-mode-map "\C-i" 'emacspeak-speak-next-field)
   (define-key dired-mode-map  "," 'emacspeak-speak-previous-field))
-(add-hook 'dired-mode-hook 'emacspeak-dired-initialize 'append)
-(add-hook 'dired-mode-hook 'emacspeak-dired-setup-keys)
-(add-hook 'dired-mode-hook 'emacspeak-dired-define-pronunciations)
+(add-hook 'emacspeak-dired-initialize 'append)
+
 ;;}}}
 (provide 'emacspeak-dired)
 ;;{{{ emacs local variables
