@@ -1,5 +1,5 @@
 ;;; emacspeak-emms.el --- Speech-enable EMMS Multimedia UI
-;;; $Id: emacspeak-emms.el 5228 2007-08-28 00:54:54Z tv.raman.tv $
+;;; $Id: emacspeak-emms.el 8146 2013-02-09 20:05:08Z tv.raman.tv $
 ;;; $Author: tv.raman.tv $
 ;;; Description:  Emacspeak extension to speech-enable EMMS
 ;;; Keywords: Emacspeak, Multimedia
@@ -16,7 +16,7 @@
 ;;}}}
 ;;{{{  Copyright:
 
-;;; Copyright (C) 1995--2004 T. V. Raman <raman@cs.cornell.edu>
+;;; Copyright (C) 1995--2004, 2011 T. V. Raman <raman@cs.cornell.edu>
 ;;; All Rights Reserved.
 ;;;
 ;;; This file is not part of GNU Emacs, but the same permissions apply.
@@ -62,7 +62,7 @@
   "Speak current track."
   (interactive)
   (message
-   (cdr (assoc 'name (emms-playlist-current-track)))))
+   (cdr (assq 'name (emms-playlist-current-track)))))
 
 (loop for f in
       '(emms-next emms-next-noerror emms-previous)
@@ -70,7 +70,7 @@
       (eval
        `(defadvice ,f (after emacspeak pre act comp)
           "Speak track name."
-          (when (interactive-p)
+          (when (ems-interactive-p )
             (emacspeak-auditory-icon 'select-object)))))
 
 ;;; these commands should not be made to talk since that would  interferes
@@ -82,7 +82,7 @@
       (eval
        `(defadvice ,f (after emacspeak pre act comp)
           "Provide auditory icon."
-          (when (interactive-p)
+          (when (ems-interactive-p )
             (emacspeak-auditory-icon 'select-object)))))
 
 (loop for f in
@@ -92,9 +92,19 @@
       (eval
        `(defadvice ,f (after emacspeak pre act comp)
           "Provide auditory feedback."
-          (when (interactive-p)
+          (when (ems-interactive-p )
             (emacspeak-auditory-icon 'large-movement)
             (emacspeak-speak-line)))))
+(loop for f in
+      '(emms-browser emms-browser-next-filter
+                     emms-browser-previous-filter)
+      do
+      (eval
+       `(defadvice ,f (after emacspeak pre act comp)
+          "Provide auditory feedback."
+          (when (ems-interactive-p )
+            (emacspeak-speak-mode-line)
+            (emacspeak-auditory-icon 'open-object)))))
 
 ;;}}}
 ;;{{{ Module emms-streaming:
@@ -107,13 +117,13 @@
 (defadvice emms-stream-delete-bookmark (after emacspeak pre act
                                               comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'delete-object)
     (emacspeak-speak-line)))
 
 (defadvice emms-stream-save-bookmarks-file (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'save-object)
     (message "Saved stream bookmarks.")))
 
@@ -126,7 +136,7 @@
       (eval
        `(defadvice ,f (after emacspeak pre act comp)
           "Provide auditory feedback."
-          (when (interactive-p)
+          (when (ems-interactive-p )
             (emacspeak-speak-mode-line)))))
 
 (loop for f in
@@ -135,21 +145,45 @@
       (eval
        `(defadvice ,f (after emacspeak pre act comp)
           "Provide auditory feedback."
-          (when (interactive-p)
+          (when (ems-interactive-p )
             (emacspeak-speak-line)))))
 (defadvice emms-playlist-mode-bury-buffer (after emacspeak pre act)
   "Announce the buffer that becomes current."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'select-object)
     (emacspeak-speak-mode-line )))
-      
+
+;;}}}
+;;{{{ silence chatter from info
+
+(defadvice emms-info-really-initialize-track (around emacspeak
+                                                     pre act
+                                                     comp)
+  "Silence messages."
+  (let ((emacspeak-speak-messages nil))
+    ad-do-it))
+
+;;}}}
+;;{{{ pause/resume if needed
+
+;;;###autoload
+(defun emacspeak-emms-pause-or-resume ()
+  "Pause/resume if emms is running. For use  in
+emacspeak-silence-hook."
+  (declare (special emms-player-playing-p))
+  (when (and (boundp 'emms-player-playing-p)
+             (not (null emms-player-playing-p)))
+    (emms-player-pause)))
+
+(add-hook 'emacspeak-silence-hook 'emacspeak-emms-pause-or-resume)
+
 ;;}}}
 (provide 'emacspeak-emms)
 ;;{{{ end of file
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: t
+;;; byte-compile-dynamic: nil
 ;;; end:
 
 ;;}}}
