@@ -1,5 +1,5 @@
 ;;; emacspeak-entertain.el --- Speech enable misc games
-;;; $Id: emacspeak-entertain.el 5222 2007-08-26 01:28:19Z tv.raman.tv $
+;;; $Id: emacspeak-entertain.el 8146 2013-02-09 20:05:08Z tv.raman.tv $
 ;;; $Author: tv.raman.tv $ 
 ;;; Description: Auditory interface to diversions
 ;;; Keywords: Emacspeak, Speak, Spoken Output, games
@@ -16,7 +16,7 @@
 ;;}}}
 ;;{{{  Copyright:
 
-;;; Copyright (c) 1995 -- 2007, T. V. Raman
+;;; Copyright (c) 1995 -- 2011, T. V. Raman
 ;;; All Rights Reserved. 
 ;;;
 ;;; This file is not part of GNU Emacs, but the same permissions apply.
@@ -76,7 +76,7 @@
 (defadvice dun-parse (around emacspeak pre act comp)
   "Provide auditory feedback"
   (cond
-   ((interactive-p)
+   ((ems-interactive-p )
     (let ((orig (point)))
       ad-do-it
       (emacspeak-auditory-icon 'mark-object)
@@ -105,7 +105,7 @@
 
 (defadvice hm-self-guess-char (after eemacspeak pre act comp)
   "Speak the char."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'select-object)))
 
 (defun emacspeak-hangman-speak-guess ()
@@ -125,7 +125,7 @@
 
 (defadvice hangman (after emacseak pre act comp)
   "Speech enable hangman."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-hangman-setup-pronunciations)
     (emacspeak-auditory-icon 'open-object)))
 (declaim (special hm-map))
@@ -141,7 +141,7 @@
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: t
+;;; byte-compile-dynamic: nil
 ;;; end: 
 
 ;;}}}
