@@ -1,5 +1,5 @@
 ;;; emacspeak-eterm.el --- Speech enable eterm -- Emacs' terminal emulator  term.el
-;;; $Id: emacspeak-eterm.el 5222 2007-08-26 01:28:19Z tv.raman.tv $
+;;; $Id: emacspeak-eterm.el 8534 2013-11-13 01:43:12Z tv.raman.tv $
 ;;; $Author: tv.raman.tv $ 
 ;;; Description:  Emacspeak extension to speech enable eterm. 
 ;;; Keywords: Emacspeak, Eterm, Terminal emulation, Spoken Output
@@ -15,7 +15,7 @@
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2007, T. V. Raman 
+;;;Copyright (C) 1995 -- 2011, T. V. Raman 
 ;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
 ;;; All Rights Reserved. 
 ;;;
@@ -291,7 +291,7 @@ Pronounces character phonetically unless  called with a PREFIX arg."
   (interactive)
   (declare (special emacspeak-eterm-pointer ))
   (set-marker emacspeak-eterm-pointer (point ))
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'large-movement)
     (emacspeak-eterm-speak-cursor)))
 
@@ -302,7 +302,7 @@ Pronounces character phonetically unless  called with a PREFIX arg."
   (save-excursion
     (goto-char term-home-marker)  
     (set-marker emacspeak-eterm-pointer (point))
-    (when (interactive-p)
+    (when (ems-interactive-p )
       (emacspeak-auditory-icon 'large-movement)
       (emacspeak-speak-line nil ))))
 
@@ -313,7 +313,7 @@ Pronounces character phonetically unless  called with a PREFIX arg."
   (save-excursion
     (goto-char (point-max))
     (set-marker emacspeak-eterm-pointer (point ))
-    (when (interactive-p)
+    (when (ems-interactive-p )
       (emacspeak-auditory-icon 'large-movement)
       (emacspeak-speak-line nil ))))
 
@@ -360,7 +360,7 @@ Argument COUNT specifies number of columns by which to move."
     (goto-char emacspeak-eterm-pointer )
     (backward-char count)
     (set-marker emacspeak-eterm-pointer (point ))
-    (when (interactive-p)
+    (when (ems-interactive-p )
       (dtk-stop)
       (emacspeak-speak-char t ))))
 
@@ -374,7 +374,7 @@ Argument COUNT specifies number of columns by which to move."
     (goto-char emacspeak-eterm-pointer )
     (forward-char  count )
     (set-marker emacspeak-eterm-pointer (point ))
-    (when (interactive-p)
+    (when (ems-interactive-p )
       (dtk-stop)
       (emacspeak-speak-char t))))
 
@@ -386,7 +386,7 @@ Argument COUNT specifies number of columns by which to move."
     (goto-char emacspeak-eterm-pointer )
     (end-of-line)
     (set-marker emacspeak-eterm-pointer (point ))
-    (when (interactive-p) 
+    (when (ems-interactive-p ) 
       (dtk-stop)
       (emacspeak-auditory-icon 'large-movement)
       (emacspeak-speak-char t))))
@@ -399,7 +399,7 @@ Argument COUNT specifies number of columns by which to move."
     (goto-char emacspeak-eterm-pointer )
     (beginning-of-line)
     (set-marker emacspeak-eterm-pointer (point ))
-    (when (interactive-p)
+    (when (ems-interactive-p )
       (dtk-stop)
       (emacspeak-auditory-icon 'large-movement)
       (emacspeak-speak-char t))))
@@ -417,7 +417,7 @@ Argument COUNT specifies number of words by which to move."
         (forward-word  (- count ))
       (error nil ))
     (set-marker emacspeak-eterm-pointer (point ))
-    (when (interactive-p)
+    (when (ems-interactive-p )
       (emacspeak-speak-word))))
 
 (defun emacspeak-eterm-pointer-forward-word (count)
@@ -434,7 +434,7 @@ Argument COUNT specifies number of words by which to move."
       (error nil ))
     (skip-syntax-forward " ")
     (set-marker emacspeak-eterm-pointer (point ))
-    (when (interactive-p)
+    (when (ems-interactive-p )
       (emacspeak-speak-word))))
 
 (defun emacspeak-eterm-goto-line (line)
@@ -589,7 +589,7 @@ to by the emacspeak eterm pointer."
     (setq coordinates
           (emacspeak-eterm-position-to-coordinates
            (marker-position emacspeak-eterm-pointer)))
-    (when (interactive-p)
+    (when (ems-interactive-p )
       (emacspeak-auditory-icon 'mark-object)
       (dtk-stop)
       (message "Set eterm mark at row %s column %s"
@@ -656,7 +656,6 @@ sent to the terminal as if it were typed by the user."
     (aset win 3 left-stretch )
     win))
 
-  
 (defsubst emacspeak-eterm-window-top-left (w) (aref w 0 ))
 (defsubst emacspeak-eterm-window-bottom-right (w) (aref w 1 ))
 (defsubst emacspeak-eterm-window-right-stretch (w) (aref w 2 ))
@@ -684,7 +683,7 @@ Argument ID specifies the window."
             (> row bottom-right-row )
             (and (not left-stretch ) (< column top-left-column ))
             (and (not right-stretch ) (> column bottom-right-column )))))))
- 
+
 ;;; Translate a screen position to a buffer position
 
 (defun emacspeak-eterm-coordinates-to-position (coordinates)
@@ -1030,7 +1029,6 @@ available with the prefix emacspeak-eterm-prefix and are listed below:
   (emacspeak-eterm-setup-raw-keys)
   (make-local-variable 'eterm-current-personality)
   (setq eterm-current-personality emacspeak-eterm-default-personality)
-  (voice-lock-mode 1)
   (modify-syntax-entry 10 ">")
   (make-local-variable 'emacspeak-eterm-pointer)
   (setq emacspeak-eterm-pointer  (copy-marker (point)))
@@ -1056,9 +1054,9 @@ Each term-mode buffer has a buffer local value of this variable. ")
   "Tells if eterm output is automatically spoken when in line mode.
 Use command emacspeak-toggle-eterm-autospeak bound to
 \\[emacspeak-toggle-eterm-autospeak] to set this.")
-  
+
 (make-variable-buffer-local 'emacspeak-eterm-autospeak)
-  
+
 (ems-generate-switcher 'emacspeak-toggle-eterm-autospeak
                        'emacspeak-eterm-autospeak
                        "Toggle state of eterm autospeak.
@@ -1079,6 +1077,12 @@ Do not set this by hand.
 Use command emacspeak-eterm-toggle-pointer-mode bound to
 \\[emacspeak-eterm-toggle-pointer-mode].")
 
+(defsubst emacspeak-eterm-activity-in-window (window)
+  "T if terminal activity within bounds of window."
+  (emacspeak-eterm-coordinate-within-window-p
+   (cons (term-current-column) (term-current-row))
+   window))
+
 (defadvice  term-emulate-terminal (around emacspeak pre act compile )
   "Record position, emulate, then speak what happened.
 Also keep track of terminal highlighting etc.  Feedback is
@@ -1098,7 +1102,8 @@ emacspeak-toggle-eterm-autospeak bound to
                     emacspeak-eterm-filter-window emacspeak-eterm-pointer-mode
                     emacspeak-eterm-autospeak 
                     term-current-row term-current-column))
-  (let ((emacspeak-eterm-row (term-current-row ))
+  (let ((emacspeak-eterm-window (get-buffer-window (process-buffer (ad-get-arg 0))))
+        (emacspeak-eterm-row (term-current-row ))
         (emacspeak-eterm-column (term-current-column ))
         (end (point-max))
         (current-char (preceding-char ))
@@ -1111,22 +1116,12 @@ emacspeak-toggle-eterm-autospeak bound to
     (setq new-row (term-current-row )
           new-column (term-current-column )
           new-end (point-max))
-    (when (and  emacspeak-eterm-autospeak
-                (window-live-p
-                 (get-buffer-window (process-buffer (ad-get-arg 0))))
-                (or  (not emacspeak-eterm-focus-window )
-                     (and (emacspeak-eterm-coordinate-within-window-p
-                           (cons new-column new-row )
-                           emacspeak-eterm-focus-window )
-                          (emacspeak-eterm-coordinate-within-window-p
-                           (cons (term-current-column) (term-current-row))
-                           emacspeak-eterm-focus-window ))
-                     (and (emacspeak-eterm-coordinate-within-window-p
-                           (cons new-column new-row )
-                           emacspeak-eterm-filter-window )
-                          (emacspeak-eterm-coordinate-within-window-p
-                           (cons (term-current-column) (term-current-row))
-                           emacspeak-eterm-filter-window ))))
+    (when                        ; do something if in active area
+        (and  emacspeak-eterm-autospeak
+              (window-live-p emacspeak-eterm-window)
+              (or  (not emacspeak-eterm-focus-window )
+                   (emacspeak-eterm-activity-in-window  emacspeak-eterm-focus-window)
+                   (emacspeak-eterm-activity-in-window  emacspeak-eterm-filter-window)))
       (cond
        ((and eterm-char-mode
              emacspeak-eterm-filter-window
@@ -1171,8 +1166,7 @@ emacspeak-toggle-eterm-autospeak bound to
                             (emacspeak-speak-word))        
           (emacspeak-speak-word )))
        (t (emacspeak-speak-line nil )))
-      (when (and (not  emacspeak-eterm-pointer-mode )
-                 emacspeak-eterm-pointer)
+      (when (and (not  emacspeak-eterm-pointer-mode ) emacspeak-eterm-pointer)
         (emacspeak-eterm-pointer-to-cursor)))))
 
 (ems-generate-switcher 'emacspeak-eterm-toggle-pointer-mode
@@ -1183,7 +1177,6 @@ When emacspeak eterm is in pointer mode, the eterm read pointer
 stays where it is rather than automatically moving to the terminal cursor when
 there is terminal activity.")
 
-   
 (defadvice term-dynamic-complete (around emacspeak pre act)
   "Speak the completion. "
   (declare (special emacspeak-eterm-row term-current-row))
@@ -1204,7 +1197,7 @@ there is terminal activity.")
         '("line"))
   (setq eterm-char-mode nil 
         eterm-line-mode t )
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (dtk-speak "Terminal line mode ")))
 
 (defadvice term-char-mode (after emacspeak pre act)
@@ -1214,7 +1207,7 @@ there is terminal activity.")
   (setq eterm-char-mode t
         eterm-line-mode nil )
   (emacspeak-eterm-setup-raw-keys)
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (dtk-speak "Terminal character mode ")))
 
 ;;}}}
@@ -1222,32 +1215,32 @@ there is terminal activity.")
 
 (defadvice term-next-input (after emacspeak pre act)
   "Speak the line. "
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-speak-line )))
 
 (defadvice term-next-matching-input (after emacspeak pre act)
   "Speak the line. "
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-speak-line )))
 
 (defadvice term-previous-input (after emacspeak pre act)
   "Speak the line. "
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-speak-line )))
 
 (defadvice term-previous-matching-input (after emacspeak pre act)
   "Speak the line. "
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-speak-line )))
 
 (defadvice term-send-input (after emacspeak pre act)
   "Flush any ongoing speech"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (dtk-stop)))
 
 (defadvice term-previous-prompt (after emacspeak pre act )
   "Provide spoken feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'large-movement)
     (if (eolp)
         (emacspeak-speak-line)
@@ -1255,7 +1248,7 @@ there is terminal activity.")
 
 (defadvice term-next-prompt (after emacspeak pre act )
   "Provide spoken feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'large-movement)
     (if (eolp)
         (emacspeak-speak-line)
@@ -1266,28 +1259,28 @@ there is terminal activity.")
 
 (defadvice term-kill-output (after emacspeak pre act )
   "Provide auditory feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'delete-object)
     (message "Nuked output of last command ")))
 
 (defadvice term-quit-subjob (after emacspeak pre act )
   "Provide auditory feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (message "Sent quit signal to subjob ")))
 
 (defadvice term-stop-subjob (after emacspeak pre act )
   "Provide auditory feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (message "Stopped the subjob")))
 
 (defadvice term-interrupt-subjob (after emacspeak pre act )
   "Provide auditory feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (message "Interrupted  the subjob")))
 
 (defadvice term-kill-input (before emacspeak pre act )
   "Provide spoken feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (let ((pmark (process-mark (get-buffer-process (current-buffer)))))
       (when  (> (point) (marker-position pmark))
         (emacspeak-auditory-icon 'delete-object )
@@ -1295,7 +1288,7 @@ there is terminal activity.")
 
 (defadvice term-dynamic-list-filename-completions (after emacspeak pre act )
   "Provide auditory feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (message "Switch to the completions window to browse the possible
 completions for filename at point")))
 
@@ -1322,7 +1315,7 @@ emacspeak-eterm-remote-hostnames")
   (when (file-exists-p emacspeak-eterm-remote-hosts-cache )
     (let ((host nil)
           (hosts (find-file-noselect emacspeak-eterm-remote-hosts-cache)))
-      (save-excursion
+      (save-current-buffer
         (set-buffer hosts)
         (goto-char (point-min))
         (while (not (eobp))
@@ -1342,7 +1335,7 @@ emacspeak-eterm-remote-hostnames")
                     emacspeak-eterm-remote-hosts-cache))
   (let ((buffer (find-file-noselect
                  emacspeak-eterm-remote-hosts-cache)))
-    (save-excursion
+    (save-current-buffer
       (set-buffer buffer)
       (goto-char (point-max))
       (insert (format "%s\n" host))
@@ -1363,14 +1356,14 @@ emacspeak-eterm-remote-hostnames")
   (unless (intern-soft host emacspeak-eterm-remote-hosts-table)
     (emacspeak-eterm-cache-remote-host host))
   (switch-to-buffer (format "*%s-terminal*" host) ))
-     
+
 ;;}}}
 (provide 'emacspeak-eterm)
 ;;{{{  emacs local variables
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: t
+;;; byte-compile-dynamic: nil
 ;;; end: 
 
 ;;}}}
