@@ -1,5 +1,5 @@
 ;;; emacspeak-eudc.el --- Speech enable  directory client 
-;;; $Id: emacspeak-eudc.el 5222 2007-08-26 01:28:19Z tv.raman.tv $
+;;; $Id: emacspeak-eudc.el 8574 2013-11-24 02:01:07Z tv.raman.tv $
 ;;; $Author: tv.raman.tv $
 ;;; Description:   extension to speech enable universal directory client 
 ;;; Keywords: Emacspeak, Audio Desktop
@@ -16,7 +16,7 @@
 ;;}}}
 ;;{{{  Copyright:
 
-;;; Copyright (C) 1995 -- 2007, T. V. Raman<raman@cs.cornell.edu>
+;;; Copyright (C) 1995 -- 2011, T. V. Raman<raman@cs.cornell.edu>
 ;;; All Rights Reserved.
 ;;;
 ;;; This file is not part of GNU Emacs, but the same permissions apply.
@@ -57,14 +57,14 @@
 
 (defadvice eudc-move-to-next-record (after emacspeak pre act comp)
   "Provide auditory feedback. "
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'select-object)
     (emacspeak-speak-line)))
 
 (defadvice eudc-move-to-previous-record (after emacspeak pre act
                                                comp)
   "Provide auditory feedback. "
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'select-object)
     (emacspeak-speak-line)))
 
@@ -142,10 +142,6 @@ Summarize the form to welcome the user. "
 ;;}}}
 ;;{{{ voiceify values in results 
 
-(defadvice eudc-mode (before emacspeak pre act comp)
-  "Setup for voiceification"
-  (voice-lock-mode 1))
-
 (defgroup emacspeak-eudc nil
   "Emacspeak add-on to the Emacs Universal Directory Client."
   :group 'emacspeak
@@ -166,10 +162,10 @@ Summarize the form to welcome the user. "
     ad-do-it)
    (t (let ((start (point)))
         ad-do-it
-        (ems-modify-buffer-safely
-         (put-text-property start (point)
-                            'personality
-                            emacspeak-eudc-attribute-value-personality)))))
+        (with-silent-modifications
+          (put-text-property start (point)
+                             'personality
+                             emacspeak-eudc-attribute-value-personality)))))
   ad-return-value)
 
 ;;}}}
@@ -178,7 +174,7 @@ Summarize the form to welcome the user. "
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: t
+;;; byte-compile-dynamic: nil
 ;;; end:
 
 ;;}}}
