@@ -1,5 +1,5 @@
 ;;; emacspeak-ido.el --- speech-enable ido
-;;; $Id: emacspeak-ido.el 8434 2013-10-23 00:28:28Z tv.raman.tv $
+;;; $Id: emacspeak-ido.el 9116 2014-04-30 16:23:49Z tv.raman.tv $
 ;;; $Author: tv.raman.tv $
 ;;; Description:   extension to speech enable ido
 ;;; Keywords: Emacspeak, Audio Desktop
@@ -130,7 +130,8 @@ The default value of 12 is too high for using ido effectively with speech. "
     (dtk-speak
      (format "Prefix %s"
              (if ido-enable-prefix 'on 'off)))))
-
+;;; forward declaration
+(defvar ido-process-ignore-lists) 
 (defadvice ido-toggle-ignore (after emacspeak pre act comp)
   "Provide auditory feedback."
   (when (ems-interactive-p )
