@@ -1,5 +1,5 @@
 ;;; emacspeak-info.el --- Speech enable Info -- Emacs' online documentation viewer
-;;; $Id: emacspeak-info.el 5222 2007-08-26 01:28:19Z tv.raman.tv $
+;;; $Id: emacspeak-info.el 8577 2013-11-25 16:34:15Z tv.raman.tv $
 ;;; $Author: tv.raman.tv $
 ;;; Description:  Module for customizing Emacs info
 ;;; Keywords:emacspeak, audio interface to emacs
@@ -15,7 +15,7 @@
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2007, T. V. Raman
+;;;Copyright (C) 1995 -- 2011, T. V. Raman
 ;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
 ;;; All Rights Reserved.
 ;;;
@@ -43,7 +43,7 @@
 ;;}}}
 ;;{{{ requires
 (require 'emacspeak-preamble)
-(eval-when-compile (require 'info))
+(require 'info)
 ;;}}}
 ;;{{{  Variables:
 
@@ -57,6 +57,7 @@
 ;;{{{  Voices
 (voice-setup-add-map
  '(
+   (info-index-match 'voice-bolden-medium)
    (info-title-1 voice-bolden-extra)
    (info-title-2 voice-bolden-medium)
    (info-title-3 voice-bolden)
@@ -104,22 +105,24 @@ node -- speak the entire node."
      ((eq emacspeak-info-select-node-speak-chunk 'node)
       (emacspeak-speak-buffer ))
      (t (emacspeak-speak-line)))))
-
-(defadvice Info-select-node (after emacspeak pre act)
-  "Voiceify the Info node if requested.
-Speak the selected node based on setting of
+(loop for f in
+      '(info-display-manual Info-select-node)
+      do
+      (eval
+       `(defadvice ,f (after emacspeak pre act)
+          " Speak the selected node based on setting of
 emacspeak-info-select-node-speak-chunk"
-  (emacspeak-info-visit-node))
+          (emacspeak-info-visit-node))))
 
 (defadvice info (after emacspeak pre act)
   "Cue user that info is up."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'help)
     (emacspeak-speak-line)))
 
 (defadvice Info-scroll-up (after emacspeak pre act)
   "Speak the screenful."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'scroll)
     (let ((start  (point ))
           (window (get-buffer-window (current-buffer ))))
@@ -129,7 +132,7 @@ emacspeak-info-select-node-speak-chunk"
 
 (defadvice Info-scroll-down (after emacspeak pre act)
   "Speak the screenful."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'scroll)
     (let ((start  (point ))
           (window (get-buffer-window (current-buffer ))))
@@ -140,19 +143,19 @@ emacspeak-info-select-node-speak-chunk"
 (defadvice Info-exit (after emacspeak pre act)
   "Play an auditory icon to close info,
 and then cue the next selected buffer."
-  (when (interactive-p )
+  (when (ems-interactive-p  )
     (dtk-stop)
     (emacspeak-auditory-icon 'close-object)
     (emacspeak-speak-mode-line)))
 
 (defadvice Info-next-reference (after emacspeak pre act)
   "Speak the line. "
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-speak-line)))
 
 (defadvice Info-prev-reference (after emacspeak pre act)
   "Speak the line. "
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-speak-line)))
 
 ;;}}}
@@ -163,26 +166,18 @@ and then cue the next selected buffer."
   (interactive)
   (declare (special Info-use-header-line
                     Info-header-line))
-  (let ((voice-lock-mode t))
-    (cond
-     ((and (boundp 'Info-use-header-line)
-           (boundp 'Info-header-line)
-           Info-header-line)
-      (dtk-speak Info-header-line))
-     (t (save-excursion
-          (goto-char (point-min))
-          (emacspeak-speak-line))))))
+  (let (cond
+        ((and (boundp 'Info-use-header-line)
+              (boundp 'Info-header-line)
+              Info-header-line)
+         (dtk-speak Info-header-line))
+        (t (save-excursion
+             (goto-char (point-min))
+             (emacspeak-speak-line))))))
 
 ;;}}}
 ;;{{{  Emacs 21
-;;; There is a bug in Emacs 21 that causes info-extract-pointer to be
-;;; called erroneously.
 
-(defadvice Info-extract-pointer  (around emacspeak pre act comp)
-  "Silence emacspeak during call."
-  (let ((emacspeak-speak-messages nil)
-        (emacspeak-use-auditory-icons nil))
-    ad-do-it))
 ;;}}}
 ;;{{{ keymaps
 (declaim (special Info-mode-map))
@@ -204,12 +199,13 @@ node-spec."
   (emacspeak-info-visit-node))
 
 ;;}}}
+
 (provide  'emacspeak-info)
 ;;{{{  emacs local variables
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: t
+;;; byte-compile-dynamic: nil
 ;;; end:
 
 ;;}}}
