@@ -1,6 +1,6 @@
 ;;; emacspeak-man.el --- Speech enable Man mode -- Use this for UNIX Man pages
-;;; $Id: emacspeak-man.el,v 23.505 2005/11/25 16:30:50 raman Exp $
-;;; $Author: raman $ 
+;;; $Id: emacspeak-man.el 8433 2013-10-23 00:24:02Z tv.raman.tv $
+;;; $Author: tv.raman.tv $ 
 ;;; DescriptionEmacspeak extensions for man-mode
 ;;; Keywords:emacspeak, audio interface to emacs man 
 ;;{{{  LCD Archive entry: 
@@ -8,14 +8,14 @@
 ;;; LCD Archive Entry:
 ;;; emacspeak| T. V. Raman |raman@cs.cornell.edu 
 ;;; A speech interface to Emacs |
-;;; $Date: 2005/11/25 16:30:50 $ |
-;;;  $Revision: 23.505 $ | 
+;;; $Date: 2008-06-21 10:50:41 -0700 (Sat, 21 Jun 2008) $ |
+;;;  $Revision: 4546 $ | 
 ;;; Location undetermined
 ;;;
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2004, T. V. Raman 
+;;;Copyright (C) 1995 -- 2011, T. V. Raman 
 ;;; Copyright (c) 1995 by T. V. Raman 
 ;;; All Rights Reserved. 
 ;;;
@@ -73,60 +73,65 @@ Also provide an auditory icon"
   (setq imenu-generic-expression
         '((nil "\n\\([A-Z].*\\)" 1)     ; SECTION, but not TITLE
           ("*Subsections*" "^   \\([A-Z].*\\)" 1)))
-  (voice-lock-mode 1)
   (dtk-set-punctuations 'all)
   (emacspeak-pronounce-refresh-pronunciations)
   (emacspeak-auditory-icon 'help))
 
 (defadvice   Man-goto-section  (after emacspeak pre act )
   "Speak the line"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'large-movement)
     (emacspeak-speak-line )))
 
 (defadvice   Man-goto-page  (after emacspeak pre act )
   "Speak the line"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'large-movement)
     (emacspeak-speak-line )))
 (defadvice   Man-next-manpage  (after emacspeak pre act )
   "Speak the line"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'large-movement)
     (emacspeak-speak-line )))
 (defadvice   Man-previous-manpage  (after emacspeak pre act )
   "Speak the line"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'large-movement)
     (emacspeak-speak-line )))
 
 (defadvice Man-next-section (after emacspeak pre act )
   "Speak the line"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'large-movement)
     (emacspeak-speak-line )))
 
 (defadvice Man-previous-section (after emacspeak pre act )
   "Speak the line"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'large-movement)
     (emacspeak-speak-line )))
 
 (defadvice Man-goto-see-also-section (after emacspeak pre act )
   "Speak the line"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'large-movement)
     (emacspeak-speak-line )))
 
 (defadvice Man-quit (after emacspeak pre act )
   "Announce buffer that is current"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'close-object)
     (emacspeak-speak-mode-line )))
 
-(defadvice manual-entry (after emacspeak pre act )
+(defadvice Man-kill (after emacspeak pre act )
+  "Announce buffer that is current"
+  (when (ems-interactive-p )
+    (emacspeak-auditory-icon 'close-object)
+    (emacspeak-speak-mode-line )))
+
+(defadvice man (after emacspeak pre act )
   "Provide auditory feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-speak-mode-line )))
 
 ;;}}}
@@ -142,7 +147,7 @@ Also provide an auditory icon"
           (progn
             (Man-next-section 1)
             (setq end (point)))
-	(error (setq end (point-max))))
+        (error (setq end (point-max))))
       (emacspeak-auditory-icon 'select-object)
       (emacspeak-speak-region start end ))))
 
@@ -152,9 +157,7 @@ Also provide an auditory icon"
   (emacspeak-execute-repeatedly 'forward-paragraph))
 (autoload 'emacspeak-view-line-to-top 
   "emacspeak-view" "Move current line to top of window"  t)
-(declaim (special Man-mode-map))
-(eval-when (load)
-  (emacspeak-keymap-remove-emacspeak-edit-commands Man-mode-map))
+
 (declaim (special  Man-mode-map))
 (define-key Man-mode-map ";"
   'emacspeak-speak-current-window)
@@ -163,6 +166,8 @@ Also provide an auditory icon"
 (define-key Man-mode-map "." 'emacspeak-man-browse-man-page)
 (define-key Man-mode-map "t" 'emacspeak-view-line-to-top)
 (define-key Man-mode-map "'" 'emacspeak-speak-rest-of-buffer)
+(define-key Man-mode-map "N" 'emacspeak-speak-next-personality-chunk)
+(define-key Man-mode-map "P" 'emacspeak-speak-previous-personality-chunk)
 (define-key Man-mode-map "[" 'backward-paragraph)
 (define-key Man-mode-map "]" 'forward-paragraph)
 
@@ -172,7 +177,7 @@ Also provide an auditory icon"
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: t
+;;; byte-compile-dynamic: nil
 ;;; end: 
 
 ;;}}}
