@@ -1,5 +1,5 @@
 ;;; emacspeak-mpg123.el --- Speech enable MP3 Player
-;;; $Id: emacspeak-mpg123.el 5222 2007-08-26 01:28:19Z tv.raman.tv $
+;;; $Id: emacspeak-mpg123.el 8146 2013-02-09 20:05:08Z tv.raman.tv $
 ;;; $Author: tv.raman.tv $
 ;;; Description:  Emacspeak extension to speech-enable MP3 player
 ;;; Keywords: Emacspeak, WWW interaction
@@ -16,7 +16,7 @@
 ;;}}}
 ;;{{{  Copyright:
 
-;;; Copyright (C) 1995 -- 2007, T. V. Raman<raman@cs.cornell.edu>
+;;; Copyright (C) 1995 -- 2011, T. V. Raman<raman@cs.cornell.edu>
 ;;; All Rights Reserved.
 ;;;
 ;;; This file is not part of GNU Emacs, but the same permissions apply.
@@ -80,56 +80,54 @@ mpg123 defines this as a macro which causes compile trouble."
 
 (defadvice mpg123-backward (after emacspeak pre act comp)
   "Speak position."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-mpg123-speak-current-time)))
 
 (defadvice mpg123-forward (after emacspeak pre act comp)
   "Speak position."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-mpg123-speak-current-time)))
 (defadvice mpg123-backward-10 (after emacspeak pre act comp)
   "Speak position."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-mpg123-speak-current-time)))
 (defadvice mpg123-forward-10 (after emacspeak pre act comp)
   "Speak position."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-mpg123-speak-current-time)))
 
-  
-
 (defadvice mpg123-next-line (after emacspeak pre act comp)
   "Speak line moveed to."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'select-object)
     (emacspeak-mpg123-speak-line)))
 
 (defadvice mpg123-prev-line (after emacspeak pre act comp)
   "Speak line moveed to."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'select-object)
     (emacspeak-mpg123-speak-line)))
 
 (defadvice mpg123-mark-position (after emacspeak pre act comp)
   "Speak line moveed to."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-mpg123-speak-line)))
 
 (defadvice  mpg123-yank-line (after emacspeak pre act comp)
   "Speak track we yanked."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'yank-object)
     (emacspeak-mpg123-speak-title)))
 
 (defadvice  mpg123-kill-line (before emacspeak pre act comp)
   "Speak track we killed."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'delete-object)
     (emacspeak-mpg123-speak-title)))
 
 (defadvice  mpg123-quit (after emacspeak pre act comp)
   "Speak modeline of what becomes current."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'close-object)
     (emacspeak-speak-mode-line)))
 
@@ -265,7 +263,7 @@ to skip to the next track. "
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: t
+;;; byte-compile-dynamic: nil
 ;;; end:
 
 ;;}}}
