@@ -1,5 +1,5 @@
 ;;; emacspeak-re-builder.el --- speech-enable re-builder
-;;; $Id: emacspeak-re-builder.el 5222 2007-08-26 01:28:19Z tv.raman.tv $
+;;; $Id: emacspeak-re-builder.el 9459 2014-09-22 02:03:04Z tv.raman.tv $
 ;;; $Author: tv.raman.tv $
 ;;; Description:   extension to speech enable re-builder
 ;;; Keywords: Emacspeak, Audio Desktop
@@ -16,7 +16,7 @@
 ;;}}}
 ;;{{{  Copyright:
 
-;;; Copyright (C) 1995 -- 2007, T. V. Raman<raman@cs.cornell.edu>
+;;; Copyright (C) 1995 -- 2011, T. V. Raman<raman@cs.cornell.edu>
 ;;; All Rights Reserved.
 ;;;
 ;;; This file is not part of GNU Emacs, but the same permissions apply.
@@ -66,18 +66,18 @@
 
 (defadvice  re-builder (after emacspeak pre act comp)
   "Speak status information."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'open-object)
     (emacspeak-speak-line)))
 
 (defadvice reb-quit (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'close-object)))
 
 (defadvice reb-next-match (after emacspeak pre act comp)
   "Speak matched line."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (save-excursion
       (set-buffer reb-target-buffer)
       (emacspeak-speak-line)
@@ -85,7 +85,7 @@
 
 (defadvice reb-prev-match (after emacspeak pre act comp)
   "Speak matched line."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (save-excursion
       (set-buffer reb-target-buffer)
       (emacspeak-speak-line)
@@ -93,7 +93,7 @@
 
 (defadvice reb-toggle-case (after emacspeak pre act comp)
   "Provide spoken feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (save-excursion
       (set-buffer reb-target-buffer)
       (emacspeak-auditory-icon
@@ -101,25 +101,28 @@
 
 (defadvice reb-copy (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'yank-object)))
 
 (defun reb-enter-subexp-mode (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'open-object)))
 (defadvice reb-quit-subexp-mode (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'close-object)))
 
+(defadvice reb-auto-update (after emacspeak pre act comp)
+  "Provide spoken feedback after update is done."
+  (emacspeak-speak-message-again))
 ;;}}}
 (provide 'emacspeak-re-builder)
 ;;{{{ end of file
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: t
+;;; byte-compile-dynamic: nil
 ;;; end:
 
 ;;}}}
