@@ -1,5 +1,5 @@
 ;;; emacspeak-tdtd.el --- Speech enable  DTD authoring 
-;;; $Id: emacspeak-tdtd.el 5222 2007-08-26 01:28:19Z tv.raman.tv $
+;;; $Id: emacspeak-tdtd.el 8146 2013-02-09 20:05:08Z tv.raman.tv $
 ;;; $Author: tv.raman.tv $
 ;;; Description:   extension to speech enable tdtd 
 ;;; Keywords: Emacspeak, Audio Desktop
@@ -16,7 +16,7 @@
 ;;}}}
 ;;{{{  Copyright:
 
-;;; Copyright (C) 1995 -- 2007, T. V. Raman<raman@cs.cornell.edu>
+;;; Copyright (C) 1995 -- 2011, T. V. Raman<raman@cs.cornell.edu>
 ;;; All Rights Reserved.
 ;;;
 ;;; This file is not part of GNU Emacs, but the same permissions apply.
@@ -58,7 +58,6 @@
 (defadvice dtd-mode (after emacspeak pre act comp)
   "set up for voice locking."
   (emacspeak-tdtd-voice-lock-setup)
-  (voice-lock-mode 1)
   (dtk-set-punctuations 'all))
 
 (defun emacspeak-tdtd-voice-lock-setup()
@@ -81,7 +80,7 @@
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: t
+;;; byte-compile-dynamic: nil
 ;;; end:
 
 ;;}}}
