@@ -1,5 +1,5 @@
 ;;; emacspeak-vm.el --- Speech enable VM -- A powerful mail agent (and the one I use)
-;;; $Id: emacspeak-vm.el 8358 2013-05-29 01:41:54Z tv.raman.tv $
+;;; $Id: emacspeak-vm.el 9502 2014-10-25 16:19:16Z tv.raman.tv $
 ;;; $Author: tv.raman.tv $
 ;;; Description:  Emacspeak extension to speech enhance vm
 ;;; Keywords: Emacspeak, VM, Email, Spoken Output, Voice annotations
@@ -120,28 +120,29 @@ Note that some badly formed mime messages  cause trouble."
 
 (defvar emacspeak-vm-user-login-name  (user-login-name)
   "Login name of this user")
-(defun emacspeak-vm-yank-header ()
-  "Yank specified header into kill ring."
-  (interactive)
-  (declare (special vm-message-pointer))
-  (cond
-   (vm-message-pointer
-    (dtk-stop)
-    (let*  ((message (car vm-message-pointer ))
-            (from (vm-from-of message ))
-            (subject (vm-subject-of  message ))
-            (to (vm-to-of message ))
-            (header nil))
-      (while (not header)
-        (setq header
-              (case
-                  (read-char "f From s Subject t To")
-                (?s subject)
-                (?f from)
-                (?t to))))
-      (kill-new header)
-      (message header)))
-   (t (error "No current message." ))))
+s(defun emacspeak-vm-yank-header ()
+   "Yank specified header into kill ring."
+   (interactive)
+   (declare (special vm-message-pointer))
+   (cond
+    (vm-message-pointer
+     (dtk-stop)
+     (let*  ((message (car vm-message-pointer ))
+             (from (vm-from-of message ))
+             (subject (vm-subject-of  message ))
+             (to (vm-to-of message ))
+             (header nil))
+       (while (not header)
+         (setq header
+               (case
+                   (read-char "f From s Subject t To")
+                 (?s subject)
+                 (?f from)
+                 (?t to))))
+       (kill-new header)
+       (message "%s" header)))
+    (t (error "No current message." ))))
+
 (defcustom emacspeak-vm-headers-strip-octals t
   "Specify whether non-ascii chars should be stripped when
   speaking email headers."
