@@ -1,5 +1,5 @@
 ;;; emacspeak-xml-shell.el --- Implements a simple XML browser
-;;; $Id: emacspeak-xml-shell.el 5246 2007-09-01 22:30:13Z tv.raman.tv $
+;;; $Id: emacspeak-xml-shell.el 8441 2013-10-23 00:59:13Z tv.raman.tv $
 ;;; $Author: tv.raman.tv $
 ;;; Description:  Contains  xml-shell
 ;;; Keywords: Emacspeak,  Audio Desktop Xml-Shell
@@ -15,7 +15,7 @@
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2007, T. V. Raman 
+;;;Copyright (C) 1995 -- 2011, T. V. Raman 
 ;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
 ;;; All Rights Reserved.
 ;;;
@@ -51,6 +51,7 @@
 
 (require 'emacspeak-preamble)
 (require 'comint)
+(require 'emacspeak-xslt)
 ;;}}}
 ;;{{{ Customizations
 ;;;###autoload
@@ -131,7 +132,7 @@ Interactive XML browser.
              (eq 'run 
                  (process-status  emacspeak-xml-shell-process)))
         emacspeak-xml-shell-document
-      (read-from-minibuffer
+      (read-file-name
        "Browse XML: "))))
   (declare (special emacspeak-xml-shell-process
                     emacspeak-xml-shell-document))
@@ -148,8 +149,7 @@ Interactive XML browser.
   (switch-to-buffer (process-buffer
                      emacspeak-xml-shell-process))
   (emacspeak-speak-mode-line))
-  
-   
+
 ;;}}}
 ;;{{{ Navigate the tree
 
@@ -332,7 +332,7 @@ HTML head if none found."
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: t
+;;; byte-compile-dynamic: nil
 ;;; end:
 
 ;;}}}
