@@ -3,7 +3,7 @@
 ;;; Code:
 
 (put 'applications 'custom-loads '(g))
-(put 'g 'custom-loads '(g-auth g-utils gblogger gbooks gcal gcontacts gdocs gfeeds ghealth gmaps gnotebook gphoto gsheet gskeleton gtube gweb))
+(put 'g 'custom-loads '(g-auth g-utils gblogger gbooks gcal gcontacts gdocs gfeeds gmaps gnotebook gphoto gsheet gskeleton gtube gweb))
 (put 'g-auth 'custom-loads '(g-auth))
 (put 'gblogger 'custom-loads '(gblogger))
 (put 'gbooks 'custom-loads '(gbooks))
@@ -11,7 +11,6 @@
 (put 'gcontacts 'custom-loads '(gcontacts))
 (put 'gdocs 'custom-loads '(gdocs))
 (put 'gfeeds 'custom-loads '(gfeeds))
-(put 'ghealth 'custom-loads '(ghealth))
 (put 'gmaps 'custom-loads '(gmaps))
 (put 'gnotebook 'custom-loads '(gnotebook))
 (put 'gphoto 'custom-loads '(gphoto))
