@@ -1,6 +1,6 @@
 ;;;Auto generated
 
-;;;### (autoloads nil "g-auth" "g-auth.el" (20980 8332 0 0))
+;;;### (autoloads nil "g-auth" "g-auth.el" (20985 36762 0 0))
 ;;; Generated autoloads from g-auth.el
 
 (defvar g-auth-lifetime "4 hours" "\
@@ -10,7 +10,7 @@ Auth lifetime.")
 
 ;;;***
 
-;;;### (autoloads nil "gblogger" "gblogger.el" (20980 8308 0 0))
+;;;### (autoloads nil "gblogger" "gblogger.el" (20762 27152 0 0))
 ;;; Generated autoloads from gblogger.el
 
 (autoload 'gblogger-blog "gblogger" "\
@@ -57,7 +57,7 @@ Resets client so you can start with a different userid.
 
 ;;;***
 
-;;;### (autoloads nil "gbooks" "gbooks.el" (20980 8308 0 0))
+;;;### (autoloads nil "gbooks" "gbooks.el" (20762 27152 0 0))
 ;;; Generated autoloads from gbooks.el
 
 (autoload 'gbooks-sign-out "gbooks" "\
@@ -72,7 +72,7 @@ Resets client so you can start with a different userid.
 
 ;;;***
 
-;;;### (autoloads nil "gcal" "gcal.el" (20980 8308 0 0))
+;;;### (autoloads nil "gcal" "gcal.el" (20762 27152 0 0))
 ;;; Generated autoloads from gcal.el
 
 (defvar gcal-default-user-email nil "\
@@ -140,7 +140,7 @@ Sign in, useful when changing to a different user profile.
 
 ;;;***
 
-;;;### (autoloads nil "gcontacts" "gcontacts.el" (20980 8308 0 0))
+;;;### (autoloads nil "gcontacts" "gcontacts.el" (20762 27152 0 0))
 ;;; Generated autoloads from gcontacts.el
 
 (autoload 'gcontacts-initialize "gcontacts" "\
@@ -155,7 +155,7 @@ Create a new contact as specified.
 
 ;;;***
 
-;;;### (autoloads nil "gdocs" "gdocs.el" (20980 8308 0 0))
+;;;### (autoloads nil "gdocs" "gdocs.el" (20762 27152 0 0))
 ;;; Generated autoloads from gdocs.el
 
 (autoload 'gdocs-doclist "gdocs" "\
@@ -197,7 +197,7 @@ Resets client so you can start with a different userid.
 
 ;;;***
 
-;;;### (autoloads nil "gfeeds" "gfeeds.el" (21299 32085 0 0))
+;;;### (autoloads nil "gfeeds" "gfeeds.el" (21560 21296 481418 94000))
 ;;; Generated autoloads from gfeeds.el
 
 (defsubst gfeeds-feed (feed-url) "\
@@ -227,22 +227,7 @@ Interactive prefix arg causes the feed url to be looked up given a Web site.
 
 ;;;***
 
-;;;### (autoloads nil "ghealth" "ghealth.el" (20980 8308 0 0))
-;;; Generated autoloads from ghealth.el
-
-(autoload 'ghealth-sign-out "ghealth" "\
-Resets client so you can start with a different userid.
-
-\(fn)" t nil)
-
-(autoload 'ghealth-sign-in "ghealth" "\
-Resets client so you can start with a different userid.
-
-\(fn)" t nil)
-
-;;;***
-
-;;;### (autoloads nil "gm-nnir" "gm-nnir.el" (21246 15149 0 0))
+;;;### (autoloads nil "gm-nnir" "gm-nnir.el" (21244 5293 0 0))
 ;;; Generated autoloads from gm-nnir.el
 
 (autoload 'gm-nnir-group-make-nnir-group "gm-nnir" "\
@@ -260,7 +245,7 @@ Default is to search All Mail when not on a Group line.
 
 ;;;***
 
-;;;### (autoloads nil "gmaps" "gmaps.el" (21339 2666 0 0))
+;;;### (autoloads nil "gmaps" "gmaps.el" (21343 55314 0 0))
 ;;; Generated autoloads from gmaps.el
 
 (autoload 'gmaps-geocode "gmaps" "\
@@ -290,7 +275,7 @@ Google Maps Interaction.
 
 ;;;***
 
-;;;### (autoloads nil "gphoto" "gphoto.el" (20980 8308 0 0))
+;;;### (autoloads nil "gphoto" "gphoto.el" (20762 27152 0 0))
 ;;; Generated autoloads from gphoto.el
 
 (autoload 'gphoto-feeds "gphoto" "\
@@ -378,7 +363,7 @@ The retrieved entry is placed in a buffer ready for editing.
 
 ;;;***
 
-;;;### (autoloads nil "gsheet" "gsheet.el" (20980 8308 0 0))
+;;;### (autoloads nil "gsheet" "gsheet.el" (20762 27152 0 0))
 ;;; Generated autoloads from gsheet.el
 
 (autoload 'gsheet-fetch "gsheet" "\
@@ -403,7 +388,7 @@ Resets client so you can start with a different userid.
 
 ;;;***
 
-;;;### (autoloads nil "gskeleton" "gskeleton.el" (20980 8308 0 0))
+;;;### (autoloads nil "gskeleton" "gskeleton.el" (20762 27152 0 0))
 ;;; Generated autoloads from gskeleton.el
 
 (autoload 'gskeleton-sign-out "gskeleton" "\
@@ -418,7 +403,7 @@ Resets client so you can start with a different userid.
 
 ;;;***
 
-;;;### (autoloads nil "gtube" "gtube.el" (20980 8308 0 0))
+;;;### (autoloads nil "gtube" "gtube.el" (20762 27152 0 0))
 ;;; Generated autoloads from gtube.el
 
 (autoload 'gtube-user-profile "gtube" "\
@@ -482,7 +467,7 @@ Retrieved featured video list.
 
 ;;;***
 
-;;;### (autoloads nil "gweb" "gweb.el" (21316 41626 0 0))
+;;;### (autoloads nil "gweb" "gweb.el" (21318 51016 0 0))
 ;;; Generated autoloads from gweb.el
 
 (defsubst gweb-google-autocomplete-with-corpus (corpus) "\
@@ -500,11 +485,11 @@ Optional interactive prefix arg refresh forces this cached URL to be refreshed.
 
 ;;;### (autoloads nil nil ("g-autogen.el" "g-cus-load.el" "g-load-path.el"
 ;;;;;;  "g-utils.el" "g.el" "gf.el" "gnotebook.el" "gwis.el" "indent-files.el"
-;;;;;;  "org2blogger.el") (21360 56743 700736 612000))
+;;;;;;  "org2blogger.el") (21621 12299 657489 444000))
 
 ;;;***
 
-;;;### (autoloads nil "g-app" "g-app.el" (20980 8332 0 0))
+;;;### (autoloads nil "g-app" "g-app.el" (21527 34501 547871 161000))
 ;;; Generated autoloads from g-app.el
 
 (autoload 'g-app-publish "g-app" "\
