@@ -70,7 +70,7 @@
 ;;; See http://feedproxy.google.com/~r/GoogleGeoDevelopersBlog/~3/0aP4dsogPJ4/introducing-new-google-geocoding-web.html
 
 (defvar gmaps-geocoder-base
-  "http://maps.google.com/maps/api/geocode/json?"
+  "https://maps.google.com/maps/api/geocode/json?"
   "Base URL  end-point for talking to the Google Maps Geocoding service.")
 
 (defsubst gmaps-geocoder-url (address)
@@ -93,16 +93,12 @@ Optional argument `raw-p' returns complete JSON  object."
          (g-json-get-result
           (format "%s --max-time 5 --connect-timeout 3 %s '%s'"
                   g-curl-program g-curl-common-options
-                  (gmaps-geocoder-url
-                   (g-url-encode address))))))
-    (unless
-        (string= "OK" (g-json-get 'status result))
+                  (gmaps-geocoder-url (g-url-encode address))))))
+    (unless (string= "OK" (g-json-get 'status result))
       (error "Error geo-coding location."))
     (cond
      (raw-p (g-json-get 'results result))
-     (t
-      (g-json-lookup "geometry.location"
-                     (aref (g-json-get 'results result) 0))))))
+     (t (g-json-path-lookup "results.[0].geometry.location" result)))))
 
 ;;;###autoload
 (defun gmaps-reverse-geocode (lat-long &optional raw-p)
@@ -120,9 +116,7 @@ Optional argument `raw-p' returns raw JSON  object."
       (error "Error reverse geo-coding."))
     (cond
      (raw-p (g-json-get 'results result))
-     (t
-     (g-json-get 'formatted_address
-                 (aref (g-json-get 'results result) 0))))))
+     (t (g-json-path-lookup "results.[0].formatted_address" result)))))
 
 ;;; Example of use:
 ;;;###autoload
@@ -151,7 +145,7 @@ Optional argument `raw-p' returns raw JSON  object."
 
 ;;; See  https://developers.google.com/maps/documentation/directions/
 (defvar gmaps-directions-base
-  "http://maps.googleapis.com/maps/api/directions/json?sensor=false&origin=%s&destination=%s&mode=%s&departure_time=%d"
+  "https://maps.googleapis.com/maps/api/directions/json?sensor=false&origin=%s&destination=%s&mode=%s&departure_time=%d"
   "Base URL  end-point for talking to the Google Maps directions service.")
 
 (defsubst gmaps-directions-url (origin destination mode)
@@ -543,14 +537,14 @@ origin/destination may be returned as a lat,long string."
 
 (defun gmaps-set-current-location (address)
   " Set current location."
-  (interactive  "sAddress: ")  (declare (special
-                                         gmaps-current-location))
+  (interactive  "sAddress: ")
+  (declare (special gmaps-current-location))
   (condition-case nil
-    (setq gmaps-current-location
-          (gmaps-geocode address))
-    (error (message "Error finding %s" address)))
+      (progn 
+    (setq gmaps-current-location (gmaps-geocode address))
     (put 'gmaps-current-location 'address address)
     (message "Moved to %s" address))
+    (error (message "Error finding %s" address))))
 
 
 (defstruct gmaps-places-filter
@@ -830,34 +824,73 @@ Optional  prefix arg clears any active filters."
                        'maps-data place)))
 
 (defun gmaps-place-details ()
-  "Display details for place at point."
+  "Display details for place at point.
+Insert reviews if already displaying details."
   (interactive)
   (declare (special g-curl-program g-curl-common-options
                     gmaps-places-key))
-  (unless (eq major-mode 'gmaps-mode)
-    (error "Not in a Google Maps buffer."))
-  (unless  (get-text-property  (point) 'maps-data)
+  (unless (eq major-mode 'gmaps-mode) (error "Not in a Google Maps buffer."))
+  (unless
+      (or (get-text-property  (point) 'maps-data)
+          (get-text-property (point) 'place-details))
     (error "No maps data at point."))
-  (let* ((start nil)
-        (inhibit-read-only t)
-        (place-ref
-         (g-json-get 'reference (get-text-property (point)'maps-data )))
-        (result
-         (and place-ref
-              (g-json-get-result
-               (format "%s --max-time 2 --connect-timeout 1 %s '%s'"
-                       g-curl-program g-curl-common-options
-                       (format "%s&%s&%s"
-                               (gmaps-places-url-base "details" gmaps-places-key)
-                               (format "reference=%s" place-ref)
-                               "extensions=review_summary"))))))
-    (cond
-                                                                     ((string= "OK" (g-json-get 'status result))
-      (put-text-property (line-beginning-position) (line-end-position)
-                         'place-details t)
-      (gmaps-display-place-details (g-json-get 'result result)))
-     (t (error "Status %s from Maps" (g-json-get 'status result))))))
+  (cond
+   ((get-text-property (point) 'place-details)
+    (gmaps-place-reviews))
+   (t
+    (let* ((start nil)
+           (inhibit-read-only t)
+           (place-ref
+            (g-json-get 'reference (get-text-property (point)'maps-data )))
+           (result
+            (and place-ref
+                 (g-json-get-result
+                  (format "%s --max-time 2 --connect-timeout 1 %s '%s'"
+                          g-curl-program g-curl-common-options
+                          (format "%s&%s"
+                                  (gmaps-places-url-base "details" gmaps-places-key)
+                                  (format "reference=%s" place-ref)))))))
+      (cond
+       ((string= "OK" (g-json-get 'status result))
+        (put-text-property (line-beginning-position) (line-end-position)
+                           'place-details t)
+        (gmaps-display-place-details (g-json-get 'result result)))
+       (t (error "Status %s from Maps" (g-json-get 'status result))))))))
 
+(defun gmaps-place-reviews ()
+  "Display reviews for place at point.
+Place details need to have been expanded first."
+  (interactive)
+  (let ((inhibit-read-only t)
+        (start (point))
+        (details (get-text-property (point) 'place-details))
+        (reviews nil))
+    (unless  details (error  "No place details here."))
+    (setq reviews (g-json-get 'reviews details))
+    (unless reviews (error "No reviews for this place."))
+    (goto-char (next-single-property-change (point)  'place-details))
+    (setq start (point))
+    (insert
+     (with-temp-buffer
+       (insert "<ol>")
+       (loop
+        for r across reviews
+        do
+        (insert
+         (format "<li><a href='%s'>%s %s</a> [%s] %s</li>\n"
+                 (g-json-get 'author_url r)
+                 (g-json-get 'author_name r)
+                 (format-time-string "%m/%d/%y"
+                                     (seconds-to-time (g-json-get 'time r)))
+                 (g-json-get 'rating r)
+                 (g-json-get 'text r))))
+       (insert "</ol>")
+       (g-html-string  (buffer-string))))
+    (set-mark (point))
+    (emacspeak-auditory-icon 'task-done)
+    (goto-char start)
+    (message (format "Inserted %d reviews"  (length reviews)))))
+    
 ;;}}}
 (provide 'gmaps)
 ;;{{{ end of file
