@@ -1,7 +1,7 @@
 /*
- * $Id: atcleci.cpp 9091 2014-04-22 01:35:24Z tv.raman.tv $
+ * $Id: atcleci.cpp 9577 2014-11-19 23:14:23Z tv.raman.tv $
  */
-// <copyright info
+//<copyright info
 
 /*
  * Tcl ViaVoiceOutloud Interface program (c) Copyright 1999 by
@@ -42,8 +42,8 @@
  * February 2005 TVR: Updating to use alsalib output routines
  */
 
-// >
-// <Usage:
+//>
+//<Usage:
 
 /*
  * TCL usage package require tts
@@ -58,8 +58,8 @@
  * text blocks as you like after a command.
  */
 
-// >
-// <includes
+//>
+//<includes
 
 #include <sys/time.h>
 #include <dlfcn.h>
@@ -73,8 +73,8 @@
 #define PACKAGEVERSION "1.0"
 #define ECILIBRARYNAME "libibmeci.so"
 
-// >
-// < alsa: globals and defines
+//>
+//< alsa: globals and defines
 
 #define DEFAULT_FORMAT SND_PCM_FORMAT_S16
 #define DEFAULT_SPEED 11025
@@ -87,8 +87,8 @@ static snd_pcm_t *AHandle = NULL;
 static snd_output_t *Log = NULL;
 short *waveBuffer = NULL;
 
-// >
-// <decls and function prototypes
+//>
+//<decls and function prototypes
 
 /*
  * The following declarations are derived from the publically
@@ -97,10 +97,7 @@ short *waveBuffer = NULL;
  * installed.
  */
 
-typedef enum {
-  eciDataNotProcessed,
-  eciDataProcessed
-} ECICallbackReturn;
+typedef enum { eciDataNotProcessed, eciDataProcessed } ECICallbackReturn;
 
 typedef enum {
   eciWaveformBuffer,
@@ -141,10 +138,10 @@ static int (*_eciGetVoiceParam)(void *, int, int);
 static int (*_eciSetVoiceParam)(void *, int, int, int);
 static int (*_eciSetOutputBuffer)(void *, int, short *);
 static int (*_eciSetOutputDevice)(void *, int);
-static void (*_eciRegisterCallback)(void *, int(*)(void *, int, long, void *),
+static void (*_eciRegisterCallback)(void *, int (*)(void *, int, long, void *),
                                     void *);
 static int alsa_init();
-static void alsa_reset(); // drop handle and reset
+static void alsa_reset();  // drop handle and reset
 static size_t alsa_configure(void);
 
 extern "C" int Atcleci_Init(Tcl_Interp *interp);
@@ -163,66 +160,66 @@ int SetLanguage(ClientData, Tcl_Interp *, int, Tcl_Obj *CONST[]);
 int alsa_close();
 int eciCallback(void *, int, long, void *);
 
-// >
-// <alsa: set hw and sw params
+//>
+//<alsa: set hw and sw params
 
 static size_t alsa_configure(void) {
-  // <init:
+  //<init:
   size_t chunk_bytes, bits_per_sample, bits_per_frame = 0;
   snd_pcm_uframes_t chunk_size, buffer_size = 0;
   snd_pcm_hw_params_t *params;
   unsigned int rate = DEFAULT_SPEED;
   int err;
   snd_pcm_hw_params_alloca(&params);
-  // >
-  // <defaults:
+  //>
+  //<defaults:
 
   err = snd_pcm_hw_params_any(AHandle, params);
   if (err < 0) {
     fprintf(stderr, "PCM: Broken configuration: no configurations available");
     exit(EXIT_FAILURE);
   }
-  // >
-  // <Format:
+  //>
+  //<Format:
 
   err = snd_pcm_hw_params_set_format(AHandle, params, DEFAULT_FORMAT);
   if (err < 0) {
     fprintf(stderr, "Sample format non available");
     exit(EXIT_FAILURE);
   }
-  // >
-  // <Channels:
+  //>
+  //<Channels:
 
   err = snd_pcm_hw_params_set_channels(AHandle, params, 1);
   if (err < 0) {
     fprintf(stderr, "Channels count non available");
     exit(EXIT_FAILURE);
   }
-  // >
-  // <Rate:
+  //>
+  //<Rate:
 
   err = snd_pcm_hw_params_set_rate_near(AHandle, params, &rate, 0);
   assert(err >= 0);
 
-  // >
-  // <Access Mode:
+  //>
+  //<Access Mode:
   err = snd_pcm_hw_params_set_access(AHandle, params,
                                      SND_PCM_ACCESS_RW_INTERLEAVED);
   if (err < 0) {
     fprintf(stderr, "Access type not available");
     exit(EXIT_FAILURE);
   }
-  // >
-  // < Set things explicitly if DEBUG
-  // >
-  // <Commit hw params:
+  //>
+  //< Set things explicitly if DEBUG
+  //>
+  //<Commit hw params:
   err = snd_pcm_hw_params(AHandle, params);
   if (err < 0) {
     fprintf(stderr, "Unable to install hw params:");
     exit(EXIT_FAILURE);
   }
-  // >
-  // <finalize chunk_size and buffer_size:
+  //>
+  //<finalize chunk_size and buffer_size:
 
   snd_pcm_hw_params_get_period_size(params, &chunk_size, 0);
   snd_pcm_hw_params_get_buffer_size(params, &buffer_size);
@@ -231,28 +228,28 @@ static size_t alsa_configure(void) {
             chunk_size, buffer_size);
     exit(EXIT_FAILURE);
   }
-  // >
-  // < If DEBUG: SW Params Configure transfer:
-  // >
+  //>
+  //< If DEBUG: SW Params Configure transfer:
+  //>
   bits_per_sample = snd_pcm_format_physical_width(DEFAULT_FORMAT);
-  bits_per_frame = bits_per_sample * 1; // mono
+  bits_per_frame = bits_per_sample * 1;  // mono
   chunk_bytes = chunk_size * bits_per_frame / 8;
   return chunk_bytes;
 }
 
-// >
-// <xrun and suspend
+//>
+//<xrun and suspend
 
 #ifndef timersub
 
-#define timersub(a, b, result)                                                 \
-  do {                                                                         \
-    (result)->tv_sec = (a)->tv_sec - (b)->tv_sec;                              \
-    (result)->tv_usec = (a)->tv_usec - (b)->tv_usec;                           \
-    if ((result)->tv_usec < 0) {                                               \
-      --(result)->tv_sec;                                                      \
-      (result)->tv_usec += 1000000;                                            \
-    }                                                                          \
+#define timersub(a, b, result)                       \
+  do {                                               \
+    (result)->tv_sec = (a)->tv_sec - (b)->tv_sec;    \
+    (result)->tv_usec = (a)->tv_usec - (b)->tv_usec; \
+    if ((result)->tv_usec < 0) {                     \
+      --(result)->tv_sec;                            \
+      (result)->tv_usec += 1000000;                  \
+    }                                                \
   } while (0)
 #endif
 
@@ -276,8 +273,8 @@ static void xrun(void) {
       fprintf(stderr, "xrun: prepare error: %s", snd_strerror(res));
       exit(EXIT_FAILURE);
     }
-    return; // ok, data should be accepted
-            // again
+    return;  // ok, data should be accepted
+             // again
   }
 
   fprintf(stderr, "read/write error, state = %s",
@@ -294,7 +291,6 @@ static void suspend(void) {
     sleep(1); /* wait until suspend flag is * * released
                */
   if (res < 0) {
-
     fprintf(stderr, "Failed. Restarting stream. ");
     fflush(stderr);
     if ((res = snd_pcm_prepare(AHandle)) < 0) {
@@ -306,15 +302,15 @@ static void suspend(void) {
   fprintf(stderr, "Done.\n");
 }
 
-// >
-// <alsa: pcm_write
+//>
+//<alsa: pcm_write
 
 static ssize_t pcm_write(short *data, size_t count) {
   ssize_t r;
   ssize_t result = 0;
   while (count > 0) {
     r = snd_pcm_writei(AHandle, data, count);
-    if (r == -EAGAIN || (r >= 0 && (size_t) r < count)) {
+    if (r == -EAGAIN || (r >= 0 && (size_t)r < count)) {
       snd_pcm_wait(AHandle, 1000);
     } else if (r == -EPIPE) {
       xrun();
@@ -333,16 +329,16 @@ static ssize_t pcm_write(short *data, size_t count) {
   return result;
 }
 
-// >
-// <alsa_reset
+//>
+//<alsa_reset
 
 void alsa_reset() {
   snd_pcm_drop(AHandle);
   snd_pcm_prepare(AHandle);
 }
 
-// >
-// <alsa_init
+//>
+//<alsa_init
 
 int alsa_init() {
   int err;
@@ -361,8 +357,8 @@ int alsa_init() {
   return chunk_bytes;
 }
 
-// >
-// <alsa_close
+//>
+//<alsa_close
 
 int alsa_close() {
   // shut down alsa
@@ -371,20 +367,20 @@ int alsa_close() {
   return TCL_OK;
 }
 
-// >
-// <eciFree
+//>
+//<eciFree
 
 void TclEciFree(ClientData eciHandle) { _eciDelete(eciHandle); }
 
-// >
-// <tcleci_init
+//>
+//<tcleci_init
 
 int Atcleci_Init(Tcl_Interp *interp) {
   int rc;
   size_t chunk_bytes = 0;
   void *eciHandle;
   void *eciLib;
-  // < configure shared library symbols
+  //< configure shared library symbols
 
   eciLib = dlopen(ECILIBRARYNAME, RTLD_LAZY);
   if (eciLib == NULL) {
@@ -393,43 +389,42 @@ int Atcleci_Init(Tcl_Interp *interp) {
     return TCL_ERROR;
   }
 
-  _eciVersion = (void(*)(char *))(unsigned long) dlsym(eciLib, "eciVersion");
-  _eciGetAvailableLanguages =
-      (int(*)(enum ECILanguageDialect *, int *))(unsigned long)
-      dlsym(eciLib, "eciGetAvailableLanguages");
-  _eciNewEx = (void * (*)(enum ECILanguageDialect))(unsigned long)
-      dlsym(eciLib, "eciNewEx");
-  _eciDelete = (void(*)(void *))(unsigned long) dlsym(eciLib, "eciDelete");
-  _eciReset = (int(*)(void *))(unsigned long) dlsym(eciLib, "eciReset");
-  _eciStop = (int(*)(void *))(unsigned long) dlsym(eciLib, "eciStop");
+  _eciVersion = (void (*)(char *))(unsigned long)dlsym(eciLib, "eciVersion");
+  _eciGetAvailableLanguages = (int (*)(enum ECILanguageDialect *, int *))(
+      unsigned long)dlsym(eciLib, "eciGetAvailableLanguages");
+  _eciNewEx = (void *(*)(enum ECILanguageDialect))(unsigned long)dlsym(
+      eciLib, "eciNewEx");
+  _eciDelete = (void (*)(void *))(unsigned long)dlsym(eciLib, "eciDelete");
+  _eciReset = (int (*)(void *))(unsigned long)dlsym(eciLib, "eciReset");
+  _eciStop = (int (*)(void *))(unsigned long)dlsym(eciLib, "eciStop");
   _eciClearInput =
-      (int(*)(void *))(unsigned long) dlsym(eciLib, "eciClearInput");
-  _eciPause = (int(*)(void *, int))(unsigned long) dlsym(eciLib, "eciPause");
+      (int (*)(void *))(unsigned long)dlsym(eciLib, "eciClearInput");
+  _eciPause = (int (*)(void *, int))(unsigned long)dlsym(eciLib, "eciPause");
   _eciSynthesize =
-      (int(*)(void *))(unsigned long) dlsym(eciLib, "eciSynthesize");
+      (int (*)(void *))(unsigned long)dlsym(eciLib, "eciSynthesize");
   _eciSynchronize =
-      (int(*)(void *))(unsigned long) dlsym(eciLib, "eciSynchronize");
-  _eciSpeaking = (int(*)(void *))(unsigned long) dlsym(eciLib, "eciSpeaking");
+      (int (*)(void *))(unsigned long)dlsym(eciLib, "eciSynchronize");
+  _eciSpeaking = (int (*)(void *))(unsigned long)dlsym(eciLib, "eciSpeaking");
   _eciInsertIndex =
-      (int(*)(void *, int))(unsigned long) dlsym(eciLib, "eciInsertIndex");
+      (int (*)(void *, int))(unsigned long)dlsym(eciLib, "eciInsertIndex");
   _eciAddText =
-      (int(*)(void *, char *))(unsigned long) dlsym(eciLib, "eciAddText");
+      (int (*)(void *, char *))(unsigned long)dlsym(eciLib, "eciAddText");
   _eciSetParam =
-      (int(*)(void *, int, int))(unsigned long) dlsym(eciLib, "eciSetParam");
-  _eciGetVoiceParam = (int(*)(void *, int, int))(unsigned long)
-      dlsym(eciLib, "eciGetVoiceParam");
-  _eciSetVoiceParam = (int(*)(void *, int, int, int))(unsigned long)
-      dlsym(eciLib, "eciSetVoiceParam");
+      (int (*)(void *, int, int))(unsigned long)dlsym(eciLib, "eciSetParam");
+  _eciGetVoiceParam = (int (*)(void *, int, int))(unsigned long)dlsym(
+      eciLib, "eciGetVoiceParam");
+  _eciSetVoiceParam = (int (*)(void *, int, int, int))(unsigned long)dlsym(
+      eciLib, "eciSetVoiceParam");
   _eciRegisterCallback =
-      (void(*)(void *, int(*)(void *, int, long, void *), void *))(
-          unsigned long) dlsym(eciLib, "eciRegisterCallback");
-  _eciSetOutputBuffer = (int(*)(void *, int, short *))(unsigned long)
-      dlsym(eciLib, "eciSetOutputBuffer");
+      (void (*)(void *, int (*)(void *, int, long, void *), void *))(
+          unsigned long)dlsym(eciLib, "eciRegisterCallback");
+  _eciSetOutputBuffer = (int (*)(void *, int, short *))(unsigned long)dlsym(
+      eciLib, "eciSetOutputBuffer");
   _eciSetOutputDevice =
-      (int(*)(void *, int))(unsigned long) dlsym(eciLib, "eciSetOutputDevice");
+      (int (*)(void *, int))(unsigned long)dlsym(eciLib, "eciSetOutputDevice");
 
-  // >
-  // < check for needed symbols
+  //>
+  //< check for needed symbols
 
   int okay = 1;
   if (!_eciNewEx) {
@@ -508,8 +503,8 @@ int Atcleci_Init(Tcl_Interp *interp) {
     Tcl_AppendResult(interp, "Missing symbols from ", ECILIBRARYNAME, NULL);
     return TCL_ERROR;
   }
-  // >
-  // <setup package, create tts handle
+  //>
+  //<setup package, create tts handle
 
   if (Tcl_PkgProvide(interp, PACKAGENAME, PACKAGEVERSION) != TCL_OK) {
     Tcl_AppendResult(interp, "Error loading ", PACKAGENAME, NULL);
@@ -532,21 +527,21 @@ int Atcleci_Init(Tcl_Interp *interp) {
     Tcl_AppendResult(interp, "Could not open text-to-speech engine", NULL);
     return TCL_ERROR;
   }
-  // >
-  // <initialize alsa
+  //>
+  //<initialize alsa
   chunk_bytes = alsa_init();
-  // <Finally, allocate waveBuffer
+  //<Finally, allocate waveBuffer
 
-  fprintf(stderr, "allocating %d samples\n", (int) chunk_bytes);
+  fprintf(stderr, "allocating %d samples\n", (int)chunk_bytes);
   waveBuffer = (short *)malloc(chunk_bytes * sizeof(short));
   if (waveBuffer == NULL) {
     fprintf(stderr, "not enough memory");
     alsa_close();
     exit(EXIT_FAILURE);
   }
-  // >
-  // >
-  // <initialize TTS
+  //>
+  //>
+  //<initialize TTS
 
   if ((_eciSetParam(eciHandle, eciInputType, 1) == -1) ||
       (_eciSetParam(eciHandle, eciSynthMode, 1) == -1) ||
@@ -557,8 +552,8 @@ int Atcleci_Init(Tcl_Interp *interp) {
   }
   _eciRegisterCallback(eciHandle, eciCallback, interp);
 
-  // >
-  // <set output to buffer
+  //>
+  //<set output to buffer
 
   rc = _eciSynchronize(eciHandle);
   if (!rc) {
@@ -571,53 +566,53 @@ int Atcleci_Init(Tcl_Interp *interp) {
     return TCL_ERROR;
   }
   fprintf(stderr, "output buffered to waveBuffer with size %d\n",
-          (int) chunk_bytes);
+          (int)chunk_bytes);
 
-  // >
-  // <register tcl commands
+  //>
+  //<register tcl commands
 
-  Tcl_CreateObjCommand(interp, "setRate", SetRate, (ClientData) eciHandle,
+  Tcl_CreateObjCommand(interp, "setRate", SetRate, (ClientData)eciHandle,
                        TclEciFree);
-  Tcl_CreateObjCommand(interp, "getRate", GetRate, (ClientData) eciHandle,
+  Tcl_CreateObjCommand(interp, "getRate", GetRate, (ClientData)eciHandle,
                        TclEciFree);
   Tcl_CreateObjCommand(interp, "ttsVersion", getTTSVersion,
-                       (ClientData) eciHandle, TclEciFree);
-  Tcl_CreateObjCommand(interp, "alsaState", showAlsaState, (ClientData) NULL,
+                       (ClientData)eciHandle, TclEciFree);
+  Tcl_CreateObjCommand(interp, "alsaState", showAlsaState, (ClientData)NULL,
                        TclEciFree);
-  Tcl_CreateObjCommand(interp, "say", Say, (ClientData) eciHandle, TclEciFree);
-  Tcl_CreateObjCommand(interp, "synth", Say, (ClientData) eciHandle, NULL);
+  Tcl_CreateObjCommand(interp, "say", Say, (ClientData)eciHandle, TclEciFree);
+  Tcl_CreateObjCommand(interp, "synth", Say, (ClientData)eciHandle, NULL);
   Tcl_CreateObjCommand(interp, "synchronize", Synchronize,
-                       (ClientData) eciHandle, TclEciFree);
-  Tcl_CreateObjCommand(interp, "stop", Stop, (ClientData) eciHandle,
+                       (ClientData)eciHandle, TclEciFree);
+  Tcl_CreateObjCommand(interp, "stop", Stop, (ClientData)eciHandle, TclEciFree);
+  Tcl_CreateObjCommand(interp, "speakingP", SpeakingP, (ClientData)eciHandle,
                        TclEciFree);
-  Tcl_CreateObjCommand(interp, "speakingP", SpeakingP, (ClientData) eciHandle,
+  Tcl_CreateObjCommand(interp, "pause", Pause, (ClientData)eciHandle,
                        TclEciFree);
-  Tcl_CreateObjCommand(interp, "pause", Pause, (ClientData) eciHandle,
-                       TclEciFree);
-  Tcl_CreateObjCommand(interp, "resume", Resume, (ClientData) eciHandle,
+  Tcl_CreateObjCommand(interp, "resume", Resume, (ClientData)eciHandle,
                        TclEciFree);
   Tcl_CreateObjCommand(interp, "setLanguage", SetLanguage,
-                       (ClientData) eciHandle, TclEciFree);
-  // >
-  // <set up index processing
+                       (ClientData)eciHandle, TclEciFree);
+  //>
+  //<set up index processing
 
-  rc = Tcl_Eval(interp, "proc index x {global tts; \
+  rc = Tcl_Eval(interp,
+                "proc index x {global tts; \
 set tts(last_index) $x}");
 
-  // >
+  //>
   return TCL_OK;
 }
 
-// >
-// <playTTS
+//>
+//<playTTS
 
 int playTTS(int count) {
   pcm_write(waveBuffer, count);
   return eciDataProcessed;
 }
 
-// >
-// <eciCallBack
+//>
+//<eciCallBack
 
 int eciCallback(void *eciHandle, int msg, long lparam, void *data) {
   Tcl_Interp *interp = (Tcl_Interp *)data;
@@ -625,16 +620,15 @@ int eciCallback(void *eciHandle, int msg, long lparam, void *data) {
     char buffer[128];
     snprintf(buffer, 128, "index %ld", lparam);
     int rc = Tcl_Eval(interp, buffer);
-    if (rc != TCL_OK)
-      Tcl_BackgroundError(interp);
+    if (rc != TCL_OK) Tcl_BackgroundError(interp);
   } else if ((msg == eciWaveformBuffer) && (lparam > 0)) {
     playTTS(lparam);
   }
   return 1;
 }
 
-// >
-// <getRate, setRate
+//>
+//<getRate, setRate
 
 int GetRate(ClientData eciHandle, Tcl_Interp *interp, int objc,
             Tcl_Obj *CONST objv[]) {
@@ -644,8 +638,7 @@ int GetRate(ClientData eciHandle, Tcl_Interp *interp, int objc,
     return TCL_ERROR;
   }
   rc = Tcl_GetIntFromObj(interp, objv[1], &voice);
-  if (rc != TCL_OK)
-    return rc;
+  if (rc != TCL_OK) return rc;
   rate = _eciGetVoiceParam(eciHandle, voice, 6 /* eciSpeed */);
   Tcl_SetObjResult(interp, Tcl_NewIntObj(rate));
   return TCL_OK;
@@ -660,11 +653,9 @@ int SetRate(ClientData eciHandle, Tcl_Interp *interp, int objc,
     return TCL_ERROR;
   }
   rc = Tcl_GetIntFromObj(interp, objv[1], &voice);
-  if (rc != TCL_OK)
-    return rc;
+  if (rc != TCL_OK) return rc;
   rc = Tcl_GetIntFromObj(interp, objv[2], &rate);
-  if (rc != TCL_OK)
-    return rc;
+  if (rc != TCL_OK) return rc;
   rc = _eciSetVoiceParam(eciHandle, voice, 6 /* eciSpeed */, rate);
   if (rc == -1) {
     Tcl_AppendResult(interp, "Could not set rate", TCL_STATIC);
@@ -676,8 +667,8 @@ int SetRate(ClientData eciHandle, Tcl_Interp *interp, int objc,
   return TCL_OK;
 }
 
-// >
-// <say
+//>
+//<say
 
 int Say(ClientData eciHandle, Tcl_Interp *interp, int objc,
         Tcl_Obj *CONST objv[]) {
@@ -700,8 +691,7 @@ int Say(ClientData eciHandle, Tcl_Interp *interp, int objc,
         return TCL_ERROR;
       }
       rc = Tcl_GetIntFromObj(interp, objv[i], &index);
-      if (rc != TCL_OK)
-        return rc;
+      if (rc != TCL_OK) return rc;
       rc = _eciInsertIndex(eciHandle, index);
       if (!rc) {
         Tcl_AppendResult(interp, "Could not insert index", TCL_STATIC);
@@ -731,10 +721,10 @@ int Say(ClientData eciHandle, Tcl_Interp *interp, int objc,
   return TCL_OK;
 }
 
-// >
-// <stop, pause, resume
+//>
+//<stop, pause, resume
 
-// <synchronize, stop
+//<synchronize, stop
 
 int Synchronize(ClientData eciHandle, Tcl_Interp *interp, int objc,
                 Tcl_Obj *CONST objv[]) {
@@ -759,7 +749,7 @@ int Stop(ClientData eciHandle, Tcl_Interp *interp, int objc,
   return TCL_ERROR;
 }
 
-// >
+//>
 
 int SpeakingP(ClientData eciHandle, Tcl_Interp *interp, int objc,
               Tcl_Obj *CONST objv[]) {
@@ -773,8 +763,7 @@ int SpeakingP(ClientData eciHandle, Tcl_Interp *interp, int objc,
 
 int Pause(ClientData eciHandle, Tcl_Interp *interp, int objc,
           Tcl_Obj *CONST objv[]) {
-  if (_eciPause(eciHandle, 1))
-    return TCL_OK;
+  if (_eciPause(eciHandle, 1)) return TCL_OK;
   Tcl_SetResult(interp, const_cast<char *>("Could not pause synthesis"),
                 TCL_STATIC);
   return TCL_ERROR;
@@ -782,15 +771,14 @@ int Pause(ClientData eciHandle, Tcl_Interp *interp, int objc,
 
 int Resume(ClientData eciHandle, Tcl_Interp *interp, int objc,
            Tcl_Obj *CONST objv[]) {
-  if (_eciPause(eciHandle, 0))
-    return TCL_OK;
+  if (_eciPause(eciHandle, 0)) return TCL_OK;
   Tcl_SetResult(interp, const_cast<char *>("Could not resume synthesis"),
                 TCL_STATIC);
   return TCL_ERROR;
 }
 
-// >
-// <getVersion
+//>
+//<getVersion
 
 int getTTSVersion(ClientData eciHandle, Tcl_Interp *interp, int objc,
                   Tcl_Obj *CONST objv[]) {
@@ -804,8 +792,8 @@ int getTTSVersion(ClientData eciHandle, Tcl_Interp *interp, int objc,
   return TCL_OK;
 }
 
-// >
-// <show alsa state
+//>
+//<show alsa state
 
 int showAlsaState(ClientData eciHandle, Tcl_Interp *interp, int objc,
                   Tcl_Obj *CONST objv[]) {
@@ -817,8 +805,8 @@ int showAlsaState(ClientData eciHandle, Tcl_Interp *interp, int objc,
   return TCL_OK;
 }
 
-// >
-// <SetLanguage
+//>
+//<SetLanguage
 
 int SetLanguage(ClientData eciHandle, Tcl_Interp *interp, int objc,
                 Tcl_Obj *CONST objv[]) {
@@ -833,9 +821,9 @@ int SetLanguage(ClientData eciHandle, Tcl_Interp *interp, int objc,
   return TCL_OK;
 }
 
-// >
-// <end of file
+//>
+//<end of file
 // local variables:
 // folded-file: t
 // end:
-// >
+//>
